<?php

###############################################################################
# estonian.php
# This is the Estonian language file for Geeklog!
#
# Copyright (C) 2000 Jason Whittenburg
# jwhitten@securitygeeks.com
#
# Estonian translation by Artur Rpp <rtr AT planet DOT ee>
#
# This program is free software; you can redistribute it and/or
# modify it under the terms of the GNU General Public License
# as published by the Free Software Foundation; either version 2
# of the License, or (at your option) any later version.
#
# This program is distributed in the hope that it will be useful,
# but WITHOUT ANY WARRANTY; without even the implied warranty of
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
# GNU General Public License for more details.
#
# You should have received a copy of the GNU General Public License
# along with this program; if not, write to the Free Software
# Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA  02111-1307, USA.
#
###############################################################################

$LANG_CHARSET = 'iso-8859-1';

###############################################################################
# Array Format:
# $LANGXX[YY]:  $LANG - variable name
#               XX    - file id number
#               YY    - phrase id number
###############################################################################

###############################################################################
# USER PHRASES - These are file phrases used in end user scripts
###############################################################################

###############################################################################
# lib-common.php

$LANG01 = array(
    1 => 'Postitajaks:',
    2 => 'loe lisaks',
    3 => 'kommentaari',
    4 => 'Toimeta',
    5 => '',
    6 => '',
    7 => '',
    8 => '',
    9 => 'Admini funktsioonid:',
    10 => 'Sisestused',
    11 => 'Lugu',
    12 => 'Blokid',
    13 => 'Rubriigid',
    14 => '',
    15 => '',
    16 => '',
    17 => 'Kasutajad',
    18 => 'SQL pring',
    19 => 'Logi vlja',
    20 => 'Kasutaja info',
    21 => 'Kasutajanimi',
    22 => 'Kasutaja ID',
    23 => 'Turvatase',
    24 => 'Anonmne',
    25 => 'Vasta',
    26 => 'Jrgnevate kommentaaride omanikuks on need, kes iganes need postitas. See leht ei vastuta nende poolt eldu eest.',
    27 => 'Vrskeim postitus',
    28 => 'Kustuta',
    29 => 'Pole kommentaare.',
    30 => 'Vanemad lood',
    31 => 'Lubatud HTML sildid:',
    32 => 'Viga, sobimatu kasutajanimi',
    33 => 'Viga, ei saanud kirjutada logifaili',
    34 => 'Viga',
    35 => 'Logi vlja',
    36 => 'Aeg',
    37 => 'Pole kasutaja lugusid',
    38 => 'Sisu jagamine',
    39 => 'Vrskenda',
    40 => 'Sul on <tt>php.ini</tt> failis <tt>register_globals = Off</tt>. Kuid Geeklogi jaoks peab olema <tt>register_globals</tt> = <strong>on</strong>. Enne jtkamist sea selle vrtuseks <strong>"on"</strong> ja taaskivita veebiserver.',
    41 => 'Klaliskasutajaid',
    42 => 'Autoriks:',
    43 => 'Vasta sellele',
    44 => 'Tase krgemal',
    45 => 'MySQL vea number',
    46 => 'MySQL veateade',
    47 => 'Lehe kasutajale',
    48 => 'Konto info',
    49 => 'eelistused',
    50 => 'Viga SQL lauses',
    51 => 'abi',
    52 => 'Uus',
    53 => 'Admin avaleht',
    54 => 'Ei saanud avada faili.',
    55 => 'Viga: koht',
    56 => 'Hleta',
    57 => 'Salasna',
    58 => 'Logi sisse',
    59 => "Pole veel kontot? Logi sisse <a href=\"{$_CONF['site_url']}/users.php?mode=new\">uue kasutajana</a>",
    60 => 'Postita kommentaar',
    61 => 'Loo uus kasutajakonto',
    62 => 'sna',
    63 => 'Kommentaaride eelistused',
    64 => 'Saada artikkel sbrale E-postiga',
    65 => 'Nita printversiooni',
    66 => '',
    67 => 'Tere siia - ',
    68 => 'Avaleht',
    69 => 'Kontakt',
    70 => 'Otsi',
    71 => 'Lisa lehele lugu',
    72 => 'Veebi kohad',
    73 => '',
    74 => '',
    75 => 'Otsing',
    76 => 'Lehe statistika',
    77 => 'Pluginad',
    78 => '',
    79 => 'Mida uut',
    80 => 'viimased lood',
    81 => 'viimane lugu',
    82 => 'tundi',
    83 => 'KOMMENTAARE',
    84 => '',
    85 => 'viimased 48 t',
    86 => 'Pole uusi kommentaare',
    87 => 'viimased 2 n',
    88 => '',
    89 => '',
    90 => 'Avaleht',
    91 => 'Leht valmis',
    92 => 'sekundiga',
    93 => '(C)',
    94 => 'Kik sellel lehel olevad kaubamrgid ja autorikaitsega materjalid kuuluvad nende igustatud omanikele.',
    95 => 'Mootoriks on',
    96 => 'Grupid',
    97 => 'Snade loetelu',
    98 => 'Pluginad',
    99 => 'LOOD',
    100 => 'Pole uusi lugusid',
    101 => '',
    102 => '',
    103 => 'DB Backupid',
    104 => 'by',
    105 => 'E-post kasutajatele',
    106 => 'Vaatamisi',
    107 => 'GL versiooni test',
    108 => 'Thjenda puhvermlu',
    109 => 'Teata kuritahtlikkusest',
    110 => 'Teata sellest postitusest lehe administraatorile',
    111 => '',
    112 => 'Registreeritud kasutajaid',
    113 => 'Dokumentatsioon',
    114 => 'TRACKBACKID',
    115 => 'Pole uusi trackback kommentaare',
    116 => 'Trackback',
    117 => 'Lood ajalises jrjestuses',
    118 => 'Palun jtka lugemist jrgmisel lehel:',
    119 => "Kaotasid oma <a href=\"{$_CONF['site_url']}/users.php?mode=getpassword\">salasna?</a>",
    120 => 'Psilink sellele kommentaarile',
    121 => 'Kommentaare (%d)',
    122 => 'Trackbacke (%d)',
    123 => 'Kogu HTML on lubatud',
    124 => 'Klpsa kigi mrgitute kustutamiseks',
    125 => 'Kas oled kindel, et soovid kiki neid kustutada?',
    126 => 'Mrgi/eemalda mrge kigilt',
    127 => 'Psilink',
    128 => 'Logi sisse OpenID abiga:',
    129 => 'Seadistus',
    130 => 'Veebiteenused'
);

###############################################################################
# comment.php

$LANG03 = array(
    1 => 'Postita kommentaar',
    2 => 'Postituse viis',
    3 => 'Logi vlja',
    4 => 'Tee konto',
    5 => 'Kasutajanimi',
    6 => 'Sellel lehel peate kommentaaride postitamiseks eelnevalt sisse logima. Kui sul ei ole veel kasutajakontot, vid alloleva vormi abiga endale konto luua.',
    7 => 'Sinu viimane kommentaar oli ',
    8 => " sekundit tagasi.  Sellel lehel  peab kommentaaride vahe olema vhemalt {$_CONF['commentspeedlimit']} sekundit",
    9 => 'kommentaar',
    10 => 'Saada raport',
    11 => 'Saada kommentaar',
    12 => 'Palun tida tiitli ja kommentaari vljad. Need on kommentaari postitamisel kohustuslikud.',
    13 => 'Info sinu kohta',
    14 => 'Eelvaade',
    15 => 'Teata sellest postitusest',
    16 => 'Tiitel',
    17 => 'Viga',
    18 => 'Oluline',
    19 => 'Hoia snum vastavuses teemaga.',
    20 => 'Proovi uue teema algatamise asemel pigem vastata teiste postitustele',
    21 => 'Loe enne postitamist teiste poolt eldut, vltides nii juba eldu kordamist.',
    22 => 'Kasuta sinu snumit selgelt kirjeldavat tiitlit.',
    23 => 'Sinu E-postiaadressi ei tehta avalikuks.',
    24 => 'Anonmne kasutaja',
    25 => 'Kas oled kindel, et soovid teatada sellest postitusest lehe administraatorile?',
    26 => '%s teatas jrgmisest kuritahtlikust postitusest:',
    27 => 'Kuritahtlikkusest teatamine',
    28 => 'Muudatuste eelvaade',
    29 => 'Sisesta muutused',
    30 => 'Muudetud',
    31 => 'muutja',
    32 => 'Kommentaari toimetamine',
    33 => 'Sisestatud kommentaari muutmine',
    34 => 'Sisestuste muutuste eelvaade',
    35 => 'Salvesta muutused puhvrisse',
    36 => 'Teavita mind vastustest',
    37 => 'Uus vastus kommentaarile',
    38 => 'Sinu kommentaarile on vastatud \'%s\'.',
    39 => 'Sa vid vaadata kommentaari lime jrgneval aadressil:',
    40 => 'Kui sa ei soovi enam saada  teaviusi vastuste kohta, klasta jrgnevat aadressit:',
    41 => 'Tere %s,',
    42 => 'Loobu tellimisest',
    43 => 'Loobu vastuste teavitustest.'
);

###############################################################################
# users.php

$LANG04 = array(
    1 => 'Kasutaja profiil, omanik',
    2 => 'Kasutajanimi',
    3 => 'Tisnimi',
    4 => 'Salasna',
    5 => 'E-postiaadress',
    6 => 'Koduleht',
    7 => 'Bio',
    8 => 'PGP vti',
    9 => 'Salvesta info',
    10 => 'Viimased 10 kommentaari, kommenteerijaks',
    11 => 'Pole kasutaja kommentaare',
    12 => 'Kasutaja eelistused, kasutaja -',
    13 => 'Saada siti kokkuvtted',
    14 => 'See salasna on genereeritud juhusliku smbolite kombinatsioonina. On soovitav, et sa vahetad koheselt salasna. Salasna muutmiseks logi oma kasutajanime ja salasna abil sisse ja ava "Lehe kasutajale" alt "Konto info".',
    15 => "Sinu {$_CONF['site_name']} konto on edukalt loodud. Selle kasutamiseks pead sa allpool oleva info abil sisse logima. Palun salvesta see kiri edaspidiseks kasutamiseks.",
    16 => 'Sinu kasutajakonto info',
    17 => 'Kontot ei ole',
    18 => 'Sisestatud E-postiaadress tundub olevat ebakorrektne E-postiaadress',
    19 => 'Kasutajanimi vi E-postiaadress on juba olemas',
    20 => 'Sisestatud E-postiaadress tundub olevat ebakorrektne E-postiaadress',
    21 => 'Viga',
    22 => "Registreeri {$_CONF['site_name']} lehel!",
    23 => "Kasutajakonto loomine annab sulle kik {$_CONF['site_name']} lehe poolt kasutajale pakutavad vimalused. Sa vid postitada oma nimega  kommentaare ja uusi lugusid. Kui sul ei ole kontot, ei saa sa neid postitada. Sinu E-postiaadressi <i><b>ei nidata kunagi</b></i> sellel lehel avalikult.",
    24 => 'Sinu salasna saadetakse siin sisestatud E-postiaadressil.',
    25 => 'Kas unustasid oma salasna?',
    26 => 'Sisesta <em>kas</em> oma kasutajanimi <em> vi </em> registreerimisel antud E-postiaadress ning klpsa Saada salasna. Antud E-postiaadressile saadetakse juhendid, kuidas mrata uus salasna.',
    27 => 'Registreeri nd!',
    28 => 'Saada salasna',
    29 => 'vlja logitud',
    30 => 'logitud sisse lehelt',
    31 => 'Sinu valitud ksk vajab, et oleksid sisse logitud',
    32 => 'Allkiri',
    33 => 'Ei nidata kunagi avalikel lehtedel',
    34 => 'See on sinu tegelik nimi',
    35 => 'Sisesta uus salasna',
    36 => 'Koos http://',
    37 => 'Rakendatakse sinu kommentaaridele',
    38 => 'See on kik sinu kohta! Kik saavad seda lugeda',
    39 => 'Sinu avalik/public PGP vti levitamiseks',
    40 => 'Pole rubriikide ikoone',
    41 => 'Soovid modereerida',
    42 => 'Kuupeva formaat',
    43 => 'Lugude maksimum',
    44 => 'pole kaste',
    45 => 'Nita eelistusi - kasutaja',
    46 => 'Vljaarvatud asjad - kasutaja',
    47 => 'Uudistekasti hlestus - kasutaja',
    48 => 'Rubriigid',
    49 => 'Lugudes pole ikoone',
    50 => 'Eemalda mrge, kui pole huvitatud',
    51 => 'Ainult uudislood',
    52 => 'Vaikimisi on',
    53 => 'Saada igal sel peval postitatud lood .',
    54 => 'Mrgi (rubriigid/autorid), mida sa ei soovi nha',
    55 => 'Kui sa jtad kik mrkimata, siis rakendatakse ssteemi vaikimisi hlestust. Kui aga alustad mrkimist, siis mrgi kindlasti kik soovitud, sest ssteemi vaikeseadistust sinule ei rakendata. Ssteemi vaikevalikud on rasvases kirjas.',
    56 => 'Autorid',
    57 => 'Nitamise viis',
    58 => 'Sorteerimisjrjekord',
    59 => 'Kommentaaride limiit',
    60 => 'Kuidas soovid, et kommentaare nitan?',
    61 => 'Uuemad vi vanemad enne',
    62 => 'Vaikimisi on 100',
    63 => "Sinu salasna saadeti sulle E-postiga ja peaks kohe kohale judma. Palun jrgi snumis olevaid juhendeid. Me tname sind {$_CONF['site_name']} kasutamise eest.",
    64 => 'Kommentaaride eelistused - kasutaja',
    65 => 'Proovi uuesti sisse logida',
    66 => "Vib-olla kirjutasid kasutajatunnuse vi salasna valesti. Palun proovi alloleva vormi abil uuesti. Vi oled <a href=\"{$_CONF['site_url']}/users.php?mode=new\">uus kasutaja?</a>",
    67 => 'Liige alates',
    68 => 'Mleta mind',
    69 => 'Kui kaua peale sisselogimist peaksin sind mletama?',
    70 => "Kohanda {$_CONF['site_name']} sisu ja vlimust",
    71 => "{$_CONF['site_name']} lehe ks headest omadustest on see, et sa vid mrata, millist sisu sulle nidatakse ja sa saad muuta lehe ldist vlimust. Selle kasutamiseks pead sa kigepealt <a href=\"{$_CONF['site_url']}/users.php?mode=new\">registreeruma</a> {$_CONF['site_name']} lehel.   Kui sa oled juba registreerinud, siis logi palun sisse.",
    72 => 'Teema',
    73 => 'Keel',
    74 => 'Saidi vlimus',
    75 => 'Rubriigid E-postiga kasutajale',
    76 => 'Kui valid allpool olevast loetelust rubriigi, saadetakse peva lpus sulle kik antud teemas postitatud lood. Vali ainult sind huvitavad teemad!',
    77 => 'Foto',
    78 => 'Lisa pilt endast!',
    79 => 'tee mrge selle pilti kustutamiseks',
    80 => 'Logi sisse',
    81 => 'Saada E-kiri',
    82 => 'Viimased 10 lugu, postitajaks',
    83 => 'Postituste statistika, autor',
    84 => 'Artiklite koguarv:',
    85 => 'Kommentaaride koguarv:',
    86 => 'Leia kik postitused - autoriks',
    87 => 'Sinu kasutajanimi',
    88 => "Keegi, vimalik, et sa ise, tellis {$_CONF['site_name']} lehel aadressiga {$_CONF['site_url']}\n\n asuva kasutajakonto \"%s\" jaoks uue salasna. Kui sa soovid seda testi teha, siis kliki alloleval lingil vi ava see leht oma veebilehitsejas:\n\n",
    89 => "Kui sa ei soovi salasna vahetada, siis ignoreeri seda E-kirja ning salasna vahetuse tellimus thistatakse (sinu salasna jb muutmata)\n\n",
    90 => 'Sa vid allpool sisestada oma konto jaoks uue salasna. Pane thele, et vana salasna on kehtiv kuni oled selle vormi titnud ja uus salasna on serveri poolt kinnitatud.',
    91 => 'Kinnita uus salasna',
    92 => 'Sisesta uus salasna',
    93 => 'Sinu viimane uue salasna tellimine toimus %d sekundit tagasi. Sellel lehel peab aga salasna tellimiste vahe olema vhemalt %d sekundit.',
    94 => 'Kustuta konto "%s"',
    95 => 'Oma kasutajakonto kustutamiseks klpsa allpool nupul Kustuta konto. Pane thele, et koos sellega ei kustutata selle kasutajakonto alt postitatud kommentaare ega jutte. Neid nidatakse edaspidi kui anonmse kasutaja poolt postitatuid.',
    96 => 'kustuta konto',
    97 => 'Kinnita kasutajakonto kustutamine',
    98 => 'Kas oled kindel, et soovid oma kasutajakonto kustutada? Prast kustutamist ei saa sa enam sellel lehel kasutajana sisse logida (kuni sa pole uut kasutajakontot loonud). Kui oled kindel, klpsa uuesti allpool olevat nuppu "Kustuta konto"',
    99 => 'Privaatsusvalikud - kasutaja',
    100 => 'E-kiri administraatorilt',
    101 => 'Luba lehe administraatoritelt E-kirju',
    102 => 'E-kirjad kasutajatelt',
    103 => 'Luba teistelt kasutajatelt E-kirju',
    104 => 'Nita online staatust',
    105 => 'Nita "Kes on online" blokis',
    106 => 'Asukoht',
    107 => 'Nidatakse sinu avalikus profiilis',
    108 => 'Kontrolliks uus salasna uuesti',
    109 => 'Kirjuta siia uuesti oma uus salasna',
    110 => 'Praegune salasna',
    111 => 'Palun sisesta oma praegune salasna',
    112 => 'Liiga mitu jrjestikust ebannestunud sisselogimist. Palun proovi hiljem uuesti.',
    113 => 'Ebannestunud sisselogimine',
    114 => 'Kontole on ligips tkestatud',
    115 => 'Ligips sinu kasutajakontole on tkestatud. Palun kontakteeru administraatoriga.',
    116 => 'Konto ootab aktiveerimist',
    117 => 'Sinu konto ootab hetkel administraatoripoolt aktiveerimist. Sa ei saa enne konto aktiveerimist sisse logida.',
    118 => "Sinu {$_CONF['site_name']} lehe konto on nd administraatori poolt aktiveeritud. Sa saad nd alloleval aadressil oma kasutajanime <username>) ja eelnevalt saadetud salasnaga sisse logida.",
    119 => 'Kui sa unustasid oma salasna vid tellida uue salasna URL-ilt',
    120 => 'Konto on aktiveeritud',
    121 => 'Teenus',
    122 => 'Kahjuks uute kasutajate registreerimine on suletud',
    123 => "Kas sa oled <a href=\"{$_CONF['site_url']}/users.php?mode=new\">uus kasutaja?</a>",
    124 => 'Kinnita E-postiaadress',
    125 => 'Sa pead sisestama sama E-postiaadressi mlemale vljale!',
    126 => 'Palun korda vigade vltimiseks',
    127 => 'Neist seadistustest kskik millise muutmiseks pead sa sisestama oma kehtiva salasna.',
    128 => 'Sinu nimi',
    129 => 'Salasna ja E-post',
    130 => 'Sinust',
    131 => 'Peva kokkuvttekirjade valikud',
    132 => 'Peva kokkuvttekirjade vimalused',
    133 => 'Kommentaaride nitamine',
    134 => 'Kommentaaride valikud',
    135 => '<li>Vaikimisi seatud kommentaaride nitamisviis</li><li>Kommentaaride sorteerimise vaikejrjekord</li><li>Sea kommentaaride maksimumarv, vaikimisi on 100</li>',
    136 => 'Arva vlja rubriigid ja autorid',
    137 => 'Filtreeri lugusid',
    138 => 'Mitmesugused valikud',
    139 => 'Vlimus ja keel',
    140 => '<li>Pole ikoone, Kui mrgitud, ei nidata rubriikide ikoone</li><li>Pole kaste, kui mrgitud nidatakse ainult Kasutaja valikuid, rubriike ja administraatoritele administraatori valikuid</li><li>Mra hel lehel maksimaalselt nidatavate lugude arv</li><li>Mra kasutatava vlimuse teema ja kuupeva formaat</li>',
    141 => 'Privaatsusseadistused',
    142 => 'Vaikimisi on mratud, et kasutajad ja administraatorid vivad saata "lehekaaslastele" E-kirju ja lehel nidatakse kui sa oled online. Eemalda mrked, et kaitsta oma privaatsust.',
    143 => 'Filtreeri kaste',
    144 => 'Nita/peida kaste',
    145 => 'Sinu avalik profiil',
    146 => 'Salasna ja E-post',
    147 => 'Muuda oma salasna, E-postiaadressi vi autologimist. Salasna ja E-postiaadressi muutmisel pead sa vigade vltimiseks sisestama need topelt.',
    148 => 'Kasutaja info',
    149 => "Muuda teistele kasutajatele nhtavat kasutajainfot. \n    <li>Allkiri lisatakse sinu kommentaaridele</li>\n    <li>Bio on lhike sinu kirjeldus teistele</li>\n    <li>Jaga oma PGP vtit</li>",
    150 => 'Mrkus: mugavamaks kasutamiseks on soovitav JavaScript.',
    156 => 'Kustuta konto',
    157 => 'Kustutamisvalik',
    158 => 'Ajavnd',
    159 => 'See E-kiri on automaatselt genereeritud . ra vasta  sellele.',
    160 => '(maks. %d x %d pikslit, %d baiti; %s)',
    161 => 'Vhendatakse',
    162 => 'Ei vhendata'
);

###############################################################################
# Customize if need to modify the Tabbed navbar MyAccount panels used.
# Array index key matches preference div id

$LANG_MYACCOUNT = array(
    'pe_preview' => 'Eelvaade',
    'pe_namepass' => 'Kasutajanimi &amp; salasna',
    'pe_userinfo' => 'Info sinust',
    'pe_layout' => 'Vlimus &amp; keel',
    'pe_content' => 'Sisu',
    'pe_privacy' => 'Privaatsus'
);

###############################################################################
# index.php

$LANG05 = array(
    1 => 'Pole midagi nidata',
    2 => 'Pole midagi nidata. Vimalik, et selles rubriigis pole htegi lugu, mida nidata vi on sinu kasutajaeelistused liiga kitsendavad, et nidata neid',
    3 => ' rubriigis %s',
    4 => 'Tnane peaartikkel',
    5 => 'Jrgmine',
    6 => 'Eelmine',
    7 => 'Esimene',
    8 => 'Viimane'
);

###############################################################################
# profiles.php

$LANG08 = array(
    1 => 'Sinu kirja saatmisel tekkis viga. Palun proovi uuesti.',
    2 => 'Snum on edukalt saadetud.',
    3 => 'Palun veendu, et saatja E-postiaadressiks oleks toimiv E-postiaadress.',
    4 => 'Palun tida "Sinu nimi", "Sinu E-postiaadress", "Teema" ja snumi vljad.',
    5 => 'Viga: pole sellist kasutajat.',
    6 => 'Oli viga..',
    7 => 'Kasutajaprofiil, omanik ',
    8 => 'Kasutaja nimi',
    9 => 'Kasutaja URL',
    10 => 'Saada E-post, kirja saajaks',
    11 => 'Sinu nimi:',
    12 => 'Sinu E-postiaadress:',
    13 => 'Teema:',
    14 => 'Snum:',
    15 => 'HTML-i ei transleerita .',
    16 => 'Valmis',
    17 => 'Saada lugu sbrale',
    18 => 'Saaja nimi',
    19 => 'E-postiaadress',
    20 => 'Saatja nimi',
    21 => 'Saatja E-postiaadress',
    22 => 'Kik vljad on kohustuslikud',
    23 => "See E-kiri saadeti sulle %s %s poolt, sest ta arvas, et sa oled huvitatud artiklist {$_CONF['site_url']} lehel.  See ei ole rmpskiri. Antud kirjaga seotud E-postiaadresseid ei silitata hilisemaks kasutamiseks!",
    24 => 'Kommenteeri seda lugu aadressil',
    25 => 'Selle vimaluse kasutamiseks pead sa lehele sisse logima. See nue aitab meil kaitsta lehte vrkasutuste eest.',
    26 => 'Selle vormi abil saad saata E-kirja valitud inimesele. Kik vljad on kohustuslikud.',
    27 => 'Lhike snum',
    28 => '%s kirjutas: ',
    29 => "See on pevane kokkuvte {$_CONF['site_name']} lehelt kasutajale.",
    30 => 'Igapevane uudiskiri kasutajale  ',
    31 => 'Tiitel',
    32 => 'Pev',
    33 => 'Loe kogu artiklit aadressil',
    34 => 'Snumi lpp',
    35 => 'Kahjuks see kasutaja ei soovi kirju saada.',
    36 => 'Koopia:',
    37 => 'Saada mulle selle kirja koopia',
    38 => "See on koopia kirjast, mille saatsid %s-le lehelt aadressiga <{$_CONF['site_url']}>:"
);

###############################################################################
# search.php

$LANG09 = array(
    1 => 'Otsing',
    2 => 'Mrksnad',
    3 => 'Rubriik',
    4 => 'Kik',
    5 => 'Tp',
    6 => 'Lood',
    7 => 'Kommentaarid',
    8 => 'Autorid',
    9 => 'Kik',
    10 => 'Otsi',
    11 => 'Otsingu tulemused',
    12 => 'Sobivaid',
    13 => 'Otsingu tulemused: ei leitud sobivaid',
    14 => 'Ei leitud sobivat otsitavale',
    15 => 'Palun proovi uuesti.',
    16 => 'Tiitel',
    17 => 'pev',
    18 => 'Postitaja',
    19 => "Otsi kigist {$_CONF['site_name']} praegustest ja eelmistest lugudest",
    20 => 'kuupev',
    21 => 'kuni',
    22 => '(kuupeva formaat AAAA-KK-PP)',
    23 => 'Vaatamisi',
    24 => 'Leidsin %d sobivat',
    25 => 'Otsiti',
    26 => 'asja ',
    27 => 'sekundit',
    28 => 'kski lugu ega kommentaar ei sobinud otsitavaga',
    29 => 'Lugude ja kommentaaride tulemus',
    30 => '',
    31 => 'See plugin ei leidnud sobivaid',
    32 => '',
    33 => 'URL',
    34 => 'Asukoht',
    35 => 'Kogu pev',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => 'Otsitav peab olema vhemalt 3 mrki pikk',
    42 => 'Palun kasuta kuupeva kujul AAAA-KK-PP(aasta-kuu-pev)',
    43 => 'tpne fraas',
    44 => 'Kik need snad',
    45 => 'vhemalt ks neist snadest',
    46 => 'Jrgmine',
    47 => 'Eelmine',
    48 => 'Autor',
    49 => 'Pev',
    50 => 'Klikke',
    51 => '',
    52 => 'Asukoht',
    53 => 'Lugude tulemus',
    54 => 'Kommentaaride tulemus',
    55 => 'fraasi',
    56 => 'JA',
    57 => 'VI',
    58 => 'Rohkem tulemusi &gt;&gt;',
    59 => 'Tulemused',
    60 => 'lehel',
    61 => ' tpsusta otsingut',
    62 => '#',
    63 => 'Kirjeldus',
    64 => 'Nitan %1$d - %2$d, kokku %3$d leitust',
    65 => 'Lugu',
    66 => 'Kommentaar',
    67 => 'Nita %d tulemust',
    68 => 'Sorteerimisalus',
    69 => 'Ainult pealkirjad',
    70 => 'Pole saadaval ...'
);

###############################################################################
# stats.php

$LANG10 = array(
    1 => 'Lehe statistika',
    2 => 'Klikkide koguarv lehtedel',
    3 => 'Lugusid (kommentaare lehtedel',
    4 => '',
    5 => '',
    6 => '',
    7 => '10 enim vaadatud lugu',
    8 => 'Loo tiitel',
    9 => 'Vaatamisi',
    10 => 'Nib, et saidil pole htegi lugu vi mitte keegi pole neid vaadanud.',
    11 => '10 enim kommenteeritud lugu',
    12 => 'Kommentaare',
    13 => 'Nib, et saidil pole htegi lugu vi mitte keegi pole neile postitanud htegi kommentaari.',
    14 => '',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => '',
    22 => 'Top 10 E-postiga saadetud lugu',
    23 => 'E-kirju',
    24 => 'Nib, et mitte keegi pole saidil saatnud htegi lugu E-postiga.',
    25 => 'Top 10 trackback abil kommenteeritud lugu',
    26 => 'Ei leidnud trackback kommentaare.',
    27 => 'Aktiivseid kasutajaid',
    28 => '',
    29 => '',
    30 => 'Klikke',
    31 => ''
);

###############################################################################
# article.php

$LANG11 = array(
    1 => 'Seotud',
    2 => 'Saada lugu sbrale',
    3 => 'Lugu prinditaval kujul',
    4 => 'Loo valikud',
    5 => '',
    6 => 'Telli \'%s\''
);

###############################################################################
# submit.php

$LANG12 = array(
    1 => 'Selleks et lisada %s pead sa kasutajana sisse logima.',
    2 => 'Logi sisse',
    3 => 'Uus kasutaja',
    4 => '',
    5 => '',
    6 => 'Lisa lugu',
    7 => 'Nutav on sisselogimine',
    8 => 'Sisesta',
    9 => "Kui lisad meie saidile uut infot, palume jrgida jrgmisi soovitusi . . .\n    <ul><li>Tida kik vljad, mis on kohustuslikud</li>\n    <li>Anna tielik ja tpne info</li>\n    <li>Kontrolli hoolikalt kirjutatud URL-id (veebiaadressid)</li></ul>",
    10 => 'Tiitel',
    11 => '',
    12 => 'Alguskuupev',
    13 => 'Lpukuupev',
    14 => 'Asukoht',
    15 => 'Kirjeldus',
    16 => '',
    17 => '',
    18 => '',
    19 => 'Loe enne',
    20 => '',
    21 => '',
    22 => 'Viga: puuduvad vljad',
    23 => 'Palun tida kik vormi vljad. Kik vljad on kohustuslikud.',
    24 => 'Sisestus on salvestatud',
    25 => 'Sinu sisestatud %s on edukalt salvestatud.',
    26 => 'Kiiruse piirang',
    27 => 'Kasutajanimi',
    28 => 'Rubriik',
    29 => 'Lugu',
    30 => 'Sinu viimane postitus oli',
    31 => " sekundit tagasi.  Sellel lehel   peab sisestuste vahe olema vhemalt {$_CONF['speedlimit']} sekundit.",
    32 => 'Eelvaade',
    33 => 'Loo eelvaade',
    34 => 'Logi vlja',
    35 => 'HTML sildid pole lubatud',
    36 => 'Postituse tp',
    37 => '',
    38 => '',
    39 => '',
    40 => '',
    41 => '',
    42 => '',
    43 => '',
    44 => 'aadressrida 1',
    45 => 'aadressrida 2',
    46 => 'linn',
    47 => 'Piirkond',
    48 => 'postiindeks',
    49 => '',
    50 => '',
    51 => 'Asukoht',
    52 => 'Kustuta',
    53 => 'Tee konto',
    54 => 'Loo kokkuvte',
    55 => 'Loo sisu'
);

###############################################################################
# ADMIN PHRASES - These are file phrases used in admin scripts
###############################################################################

###############################################################################
# admin/auth.inc.php

$LANG20 = array(
    1 => 'Nutav on autoriseerimine',
    2 => 'Tkestatud! Ebakorrektne info logimisel',
    3 => 'vigane salasna, kasutajanimi',
    4 => 'Kasutajanimi:',
    5 => 'Salasna:',
    6 => 'Kik katsed pseda ligi selle lehe administreerimisosadele logitakse ja vaadatakse lbi. <br >See leht on meldud ainult autoriseeritud kasutajatele.',
    7 => 'logi sisse'
);

###############################################################################
# admin/block.php

$LANG21 = array(
    1 => 'Ebapiisavalt administreerimisiguseid',
    2 => 'Sul ei ole piisavalt igusi selle bloki toimetamiseks.',
    3 => 'Bloki toimetaja',
    4 => 'Tekkis probleem selle lime lugemisel. Tpsemalt loe error.log failist.',
    5 => '',
    6 => '',
    7 => 'Kik',
    8 => 'Bloki turvatase',
    9 => 'Bloki jrjekord',
    10 => '',
    11 => 'Portaalblokk',
    12 => 'Normaalblokk',
    13 => 'Portaalbloki valikud',
    14 => 'RSS URL',
    15 => 'Viimane RSS uuendus',
    16 => 'Normaalbloki valikud',
    17 => 'Bloki sisu',
    18 => 'Palun tida bloki tiitli ja sisu vljad',
    19 => 'Bloki haldur',
    20 => '',
    21 => 'Bloki turva..',
    22 => '',
    23 => 'Bloki jrjekord',
    24 => '',
    25 => 'Bloki toimetamiseks vi kustutamiseks klpsa allpool selle tiitlil. Uue bloki loomiseks klpsa Tee uus lal.',
    26 => 'Kujundusblokk',
    27 => 'PHP blokk',
    28 => 'PHP bloki valikud',
    29 => 'Bloki funktsioon',
    30 => 'Kui sa soovid oma blokis kasutada PHP kske, sisesta allolevasse kasti PHP funktsiooni nimi. See peab algama eesliitega "phpblock_" (n. phpblock_getweather). Ilma selle eesliiteta funktsiooni ei kivitata. Me oleme lisanud selle kitsenduse kaitsmaks sinu saiti juhuks, kui keegi on sellele sisse hkkinud ja lisanud lehe koodi kontrollimata kske. Jlgi, et sa ei lisaks funktsiooni nime lppu sulge "()". On soovitav panna oma PHP blokkide jaoks meldud funktsioonid faili /path/to/geeklog/system/lib-custom.php. See lubab silitada lisatud PHP blockide funktsioonid ka Geeklogi uuendamisel.',
    31 => 'Viga PHP blokis.  Funktsiooni %s pole olemas.',
    32 => 'Viga: puuduvad vljad',
    33 => 'Sa pead portaalbloki jaoks sisestama RSS faili URL-i.',
    34 => 'Sa pead sisestama PHP bloki tiitli ja funktsiooni',
    35 => 'Sa pead normaalbloki jaoks sisestama tiitli ja sisu',
    36 => 'Sa pead kujundusblokkide jaoks sisestama bloki sisu',
    37 => 'Sobimatu PHP bloki funktsiooni nimi',
    38 => 'PHP blokkide jaoks meldud funktsioonid peavad algama \'phpblock_\' (n. phpblock_getweather).  \'phpblock_\' algus on kasutuses turvakaalutlustel, takistamaks kontrollimata koodi kivitamist',
    39 => 'Klg',
    40 => 'Vasak',
    41 => 'Parem',
    42 => 'Sa pead Geeklogi vaikeblokkide jaoks sisestama bloki tiitli ja jrjekorra.',
    43 => 'Ainult avaleht',
    44 => '',
    45 => "Sa ritasid ligi pseda blokile, milleks polnud sul igust. See katse logiti. Palun <a href=\"{$_CONF['site_admin_url']}/block.php\">mine tagasi blokkide administreerimislehele. </a>",
    46 => 'Uus blokk',
    47 => '',
    48 => 'Bloki nimi',
    49 => ' (ilma thikuteta ja erinev teistest)',
    50 => '',
    51 => 'koos http://',
    52 => 'Kui sa jtad selle vlja thjaks, siis selle bloki jaoks ei nidata abiikooni.',
    53 => 'kasutuses',
    54 => 'salvesta',
    55 => 'thista',
    56 => 'kustuta',
    57 => 'vii allapoole',
    58 => 'Vii lespoole',
    59 => 'Vii blokk paremale',
    60 => 'Vii blokk vasakule',
    61 => 'Pole tiitlit',
    62 => 'Artikli limiit',
    63 => 'Sobimatu bloki tiitel',
    64 => 'Tiitel peab olema ja ei tohi sisaldada HTML-i!',
    65 => 'Jrjekord',
    66 => 'Autosildid',
    67 => 'Autosiltide lubamiseks tee mrge',
    68 => 'See lim on antud portaalblokis nitamiseks liiga pikk.  Palun mra blokihalduslehel imporditavate  artiklite maksimum kas antud portaalbloki jaoks vi  siis ldine Geeklogi maksimum.'
);

###############################################################################
# admin/story.php

$LANG24 = array(
    1 => 'Eelmised lood',
    2 => 'Jrgmised lood',
    3 => 'laad',
    4 => 'Postituse viis',
    5 => 'Lugude toimetaja',
    6 => 'Ssteemis pole lugusid',
    7 => 'Autor',
    8 => 'Salvesta',
    9 => 'eelvaade',
    10 => 'thista',
    11 => 'kustuta',
    12 => 'ID',
    13 => '',
    14 => '',
    15 => 'Pev',
    16 => 'Tutvustustekst',
    17 => 'Sisutekst',
    18 => 'Klikke',
    19 => 'Kommentaare',
    20 => 'Ping',
    21 => 'Send Ping',
    22 => 'Lugude nimekiri',
    23 => 'Loo toimetamiseks vi kustutamiseks klpsa allpool loo numbril. Loo vaatamiseks klpsa selle tiitlil. Uue loo tegemiseks klpsa Tee uus lal.',
    24 => 'Loo jaoks valitud ID on juba kasutuses. Palun vali loo jaoks teine ID.',
    25 => 'Error when saving story',
    26 => 'Loo eelvaade',
    27 => '<p>If you use [unscaledX] instead of [imageX], the image will be inserted at its original dimensions.</p>',
    28 => '<p><b>EELVAADE</b>: Pilte sisaldava loo eelvaateks on parem eelvaate nupu klpsamise asemel  salvestada see mustandina.  Kasuta eelvaate nuppu ainult  siis kui pilte pole lisatud.</p>',
    29 => 'Trackbacks',
    30 => 'Faili leslaadimise vead',
    31 => 'Palun tida loo tiitli ja tutvustusteksti vljad',
    32 => 'Pealugu',
    33 => 'Korraga saab olla vaid ks pealugu',
    34 => 'Mustand',
    35 => 'Ja',
    36 => 'Ei',
    37 => 'Rohkem postitajalt',
    38 => 'Rohkem rubriigis',
    39 => 'E-kirju',
    40 => '',
    41 => "Sa proovisid ligi pseda loole, millele pole sul igust. See katse on logitud. Sa vid vaadata seda artiklit allpool ainult loetaval kujul. Palun <a href=\"{$_CONF['site_admin_url']}/story.php\">mine prast lugemist tagasi lugude administreerimislehele. </a>",
    42 => "Sa proovisid ligi pseda loole, millele pole sul igust. See katse on logitud. Palun <a href=\"{$_CONF['site_admin_url']}/story.php\">mine tagasi lugude administreerimislehele. </a>",
    43 => '',
    44 => '',
    45 => '',
    46 => '<b>MRKUS:</b> Kui sa mrad selle kuupeva tulevikku, siis seda artiklit ei avaldata enne seda peva. See thendab ka seda, et seda artiklit ei lisata varem sinu RSS voogu ja seda ignoreeritakse otsingu ja statistika lehtede poolt.',
    47 => 'Pildid',
    48 => 'pilt',
    49 => 'parem',
    50 => 'vasak',
    51 => 'Loosse lisatud piltide lehel nhtavaks tegemiseks pead sa teksti kirjutama spetsiaalsed thistused. Need thistused on kujul: [imageX], [imageX_right] vi [imageX_left], kus the X asemele tuleb panna lisatava pildi jrjenumber. Mrkus: sa pead iga lisatud pildi jaoks kirjutama vastava thistuse. Kui sa ei mra laetud piltidele asukohta, ei saa sa lugu salvestada. <p><b>Eelvaade</b>: Piltidega loo puhul on Eelvaate nupul klpsamise asemel parem lugu salvestada mustandina. Kasuta eelvaate nuppu vaid siis, kui loos pole pilte.',
    52 => '',
    53 => 'pole kasutuses. Sa pead enne muudatuste salvestamist lisama selle pildi kas tutvustusteksti vi sisu teksti.',
    54 => 'Lisatud pildid pole kasutuses',
    55 => 'Loo salvestamisel tekkisid jrgmised vead. Palun paranda need enne loo salvestamist',
    56 => 'Nita rubriigi ikooni',
    57 => 'Vaata originaalsuuruses pilti',
    58 => 'Lugude haldamine',
    59 => 'Valik',
    60 => '',
    61 => 'Autoarhiiv',
    62 => 'Autokustuta',
    63 => 'Disable Comments',
    64 => '',
    65 => '',
    66 => '',
    67 => 'Laienda sisu toimetamise ala suurust',
    68 => 'Vhenda sisu toimetamise ala suurust',
    69 => 'Publish Story Date',
    70 => 'Triistariba valik',
    71 => 'Lihtne triistariba',
    72 => 'Harilik triistariba',
    73 => 'Suur triistariba',
    74 => 'Suur II triistariba',
    75 => 'Tis philugu',
    76 => 'Avaldamise valikud',
    77 => 'Keerukama toimetaja jaoks peab lubatud olema JavaScript. Valiku saab vlja llitada saidi seadistuslehel.',
    78 => '<a href="%s/story.php?mode=edit&sid=%s&editopt=default">vaiketoimetaja kasutamiseks klpsa siia</a>',
    79 => 'Eelvaade',
    80 => 'Toimetaja',
    81 => 'Avaldamise valikud',
    82 => 'Pildid',
    83 => 'Arhiveerimisvalikud',
    84 => 'igused',
    85 => 'Nita kik',
    86 => 'Keerukam toimetaja',
    87 => 'Lugude statistika',
    88 => 'Wiki-laadne formaat',
    89 => 'Meta kirjeldus',
    90 => 'Meta mrksnad',
    91 => 'Sa vid alati klpsata "Eelvaade", et aegumisaega pikendada.'
);

###############################################################################
# admin/topic.php

$LANG27 = array(
    1 => 'Rubriikide toimetaja',
    2 => 'Rubriigi ID',
    3 => 'Rubriigi nimi',
    4 => 'Rubriigi pilt',
    5 => '(ra kasuta thikuid)',
    6 => 'Kustutades rubriigi, kustutatakse ka kik sellega seotud lood ja blokid.',
    7 => 'Palun tida rubriigi ID ja kirjelduse vljad',
    8 => 'Rubriikide haldaja',
    9 => 'Rubriigi toimetamiseks vi kustutamiseks klpsa selle nimel. Uue rubriigi lisamiseks klpsa Tee uus lal. Sa ned iga rubriigi krval sulgudes antud rubriigi jaoks oma ligipsuiguseid. Trn (*) mrgib vaikimisi valitud rubriiki.',
    10 => 'Sorteerimise jrjekord',
    11 => 'Lugusid lehel',
    12 => 'Ligips tkestatud',
    13 => "Sa proovisid pseda ligi rubriigile, milleks polnud sul igust. See ligipsukatse on logitud. Palun <a href=\"{$_CONF['site_admin_url']}/topic.php\">mine tagasi rubriikide administreerimislehele. </a>",
    14 => 'Sorteerimismeetod',
    15 => 'thestikuline',
    16 => 'vaikimisi',
    17 => 'Uus rubriik',
    18 => 'Admin avaleht',
    19 => 'salvesta',
    20 => 'thista',
    21 => 'kustuta',
    22 => 'Vaikimisi',
    23 => 'Mra see uute lugude jaoks vaikerubriigiks',
    24 => '(*)',
    25 => 'Arhiivi rubriik',
    26 => 'mra see rubriik arhiveeritud lugude  jaoks vaikerubriigiks. Ainult ks rubriik on lubatud.',
    27 => 'vi lae rubriigi ikoon',
    28 => 'Maksimum',
    29 => 'Vead faili leslaadimisel',
    30 => 'Lood rubriikides'
);

###############################################################################
# admin/user.php

$LANG28 = array(
    1 => 'Kasutajate toimetaja',
    2 => 'Kasutaja ID',
    3 => 'kasutaja nimi',
    4 => 'Tisnimi',
    5 => 'Salasna',
    6 => 'Turvatase',
    7 => 'E-postiaadress',
    8 => 'Koduleht',
    9 => '(ra kasuta thikuid)',
    10 => 'Palun tida kasutajanime ja E-postiaadressi vljad',
    11 => 'Kasutajate haldur',
    12 => 'Kasutaja andmete toimetamiseks vi konto kustutamiseks klpsa allpool soovitud kasutajal. Uue kasutajakonto loomiseks klpsa lal Tee uus. Vid teha kasutajate lihtotsingut sisestades otsingukasti osa nende kasutajanimest, E-postiaadressist vi tisnimest (niteks: mart* vi *.com).',
    13 => 'Turva..',
    14 => 'Reg. aeg',
    15 => '',
    16 => '',
    17 => '',
    18 => '',
    19 => '',
    20 => 'salvesta',
    21 => 'See kasutajanimi on juba olemas',
    22 => 'Viga',
    23 => 'Masslisamine',
    24 => 'Mass kasutajate importimine',
    25 => 'Sa vid Geeklogi importida korraga mitu kasutajat. Imporditavas tekstifailis peab vljade eraldajaks olema tabulaator ja selles peavad vljad olema jrgmises jrjekorras: tisnimi, kasutajanimi, E-postiaadress. Igale imporditud kasutajale saadetakse E-postiga salasnageneraatoriga genereeritud juhuslik salasna. hel real tohib olla vaid tpselt ks kasutaja. Selle reegli rikkumine toob kaasa probleeme, mille krvaldamine nuab lehe ksitsi hlestamist, nii et kontrolli hoolikalt ja mitu korda imporditava faili sissekandeid!',
    26 => '',
    27 => '',
    28 => 'Pildi kustutamiseks mrgi see',
    29 => 'tee',
    30 => 'Import',
    31 => 'Uued kasutajad',
    32 => 'Ttlus lpetatud. Imporditi %d ja oli %d trget',
    33 => 'sisesta',
    34 => 'Viga: pead mrama laetava faili.',
    35 => 'Viimati logitud',
    36 => '(pole)',
    37 => 'UID',
    38 => 'Gruppide nimekiri',
    39 => 'salasna (uuesti)',
    40 => 'Registreerimise aeg',
    41 => 'Viimane logimisaeg',
    42 => 'Blokeeritud',
    43 => 'Ootab aktiveerimist',
    44 => 'Ootab autoriseerimist',
    45 => 'Aktiivne',
    46 => 'Kasutaja staatus',
    47 => 'Toimeta',
    48 => 'Nita administreerimisgruppe',
    49 => 'Administreerimisgrupp',
    50 => 'Mrgi, et seda gruppi filtreeritaks administreerimisgrupina',
    51 => 'Online pevad',
    52 => '<brMrkus: Online pevad on pevade arv  registreerimisest viimase sisselogimiseni.',
    53 => 'registreeritud',
    54 => 'Masskustutamine',
    55 => 'See ttab vaid siis kui sul on config.php failis <code>$_CONF[\'lastlogin\'] = true;</code>',
    56 => 'Palun vali kasutajate rhm, mida soovid kustutada ja klpsa seejrel "Uuenda loetelu". Avanenud lehel  eemalda mrge nende kasutajate eest, keda sa ei soovi kustutada ning vajuta "Kustuta". Pane thele, et kui kasutajate loetelu on jaotatud mitmele lehele, kustutad sa ainult neid kasutajaid, mis on nhtavad antud lehel.',
    57 => 'Fantoomkasutajad',
    58 => 'Lhiaegsed kasutajad',
    59 => 'Vanad kasutajad',
    60 => 'Kasutajad, kes on registreerunud rohkem kui',
    61 => ' kuud tagasi kuid pole kunagi sisse loginud.',
    62 => 'Kasutajad, kes on registreerunud rohkem kui ',
    63 => ' kuud tagasi, seejrel loginud sisse 24 tunni jooksul kuid pole prast seda enam kordagi sinu lehele naasnud.',
    64 => 'Tavalised kasutajad, kes lihtsalt pole sinu lehele tulnud juba ',
    65 => ' kuud.',
    66 => 'Uuenda loetelu',
    67 => 'Kuud registreerimisest',
    68 => 'Online tunde',
    69 => 'Offline kuud',
    70 => 'Ei kustutatud',
    71 => 'Edukalt kustutatud',
    72 => 'Kustutamiseks pole htegi kasutajat valitud',
    73 => 'Kas sa oled kindel, et soovid lplikult kustutada kik valitud kasutajad?',
    74 => 'Viimased registreerijad',
    75 => 'Kasutajad, kes on viimati registreerunud ',
    76 => ' kuud',
    77 => 'Saada valitud kasutajatele E-kiri lehele logimise meeldetuletusega',
    78 => 'Saada meeldetuletus',
    79 => 'Meeldetuletuste jaoks pole valitud kasutajaid',
    80 => 'Meeldetuletused edukalt saadetud',
    81 => 'Meeldetuletus konto %s kontrollimiseks',
    82 => "Sinu kontot {$_CONF['site_name']}  lehel pole kasutatud %s alates ning see suletakse , kui seda ei kasutata ka jrgmise 30 peva jooksul.",
    83 => "Sinu kontot {$_CONF['site_name']} lehel pole selle tegemisest alates kasutatud ja see kustutatakse peatselt, kui seda kohe ei kasutata.",
    84 => "Meie lehel: {$_CONF['site_url']} on sinu kasutajanimi  : %s",
    85 => 'Kui unustasid oma salasna, kasuta jrgmist linki: %s',
    86 => 'Lisa',
    87 => 'Meeldetuletused'
);

###############################################################################
# admin/moderation.php

$LANG29 = array(
    1 => 'Kinnita',
    2 => 'Kustuta',
    3 => 'Toimeta',
    4 => 'Profiil',
    10 => 'Tiitel',
    11 => 'Alguspev',
    12 => 'URL',
    13 => 'Kategooria',
    14 => 'Pev',
    15 => 'Rubriik',
    16 => 'Kasutajanimi',
    17 => 'Tisnimi',
    18 => 'E-post',
    34 => 'Kontrolli ja otsusta',
    35 => 'Sisestatud lood',
    36 => 'Parent or Comment',
    37 => '',
    38 => 'Sisesta',
    39 => 'Hetkel pole levaatamist (modereerimist) vajavaid sisestusi.',
    40 => 'Kasutajate sisestused',
    41 => 'Kommentaaride sisestused',
    42 => 'Kasutaja nimi',
    43 => 'Auto-publitseeri kommentaarid?'
);

###############################################################################
# admin/mail.php

$LANG31 = array(
    1 => "{$_CONF['site_name']} E-posti triist",
    2 => 'Kellelt',
    3 => 'Vasta',
    4 => 'Teema',
    5 => 'Sisu',
    6 => 'Saada :',
    7 => 'Kik kasutajad',
    8 => 'Administraator',
    9 => 'Valikud',
    10 => 'HTML',
    11 => 'Oluline teade!',
    12 => 'Saada',
    13 => 'Puhasta',
    14 => 'Ignoreeri kasutaja seadistusi',
    15 => 'Viga saatmisel: ',
    16 => 'Edukalt saadetud: ',
    17 => "<a href={$_CONF['site_admin_url']}/mail.php>Saada jrgmine kiri</a>",
    18 => 'Kellele',
    19 => 'Kui soovid saata kirja kigile registreeritud kasutajatele, vali valikukastist Logged-in kasutajagrupp.',
    20 => "Edukalt saadetud <successcount> snumit ja ebannestus saata <failcount> snumit.  Kui sa vajad iga snumi kohta detailset infot, siis leiad selle info allpool. Kuid sa vid <a href=\"{$_CONF['site_admin_url']}/mail.php\">saata jrgmise snumi</a> vi vid <a href=\"{$_CONF['site_admin_url']}/moderation.php\">mine tagasi administreerimislehele. </a>",
    21 => 'Trked',
    22 => 'Edukalt',
    23 => 'Polnud trkeid',
    24 => 'Polnud nnestunuid',
    25 => '-- Vali grupp --',
    26 => 'Palun tida kik vljad ja vali valikukastist kasutajate grupp.'
);

###############################################################################
# admin/plugins.php

$LANG32 = array(
    1 => 'Pluginate installeerimine vib kahjustada sinu Geeklogi installatsiooni ja lisaks kahjustada ka sinu ssteemi. On oluline, et sa installeeriksid vaid <a href="http://www.geeklog.net">Geeklogi kodulehelt</a> laetud pluginaid, sest me kontrollime hoolikalt meie lehele laetud pluginaid erinevates operatsioonissteemides. On oluline mista, et plugina installeerimine nuab mitmete ssteemikskude kasutamist, mis vib kaasa tuua turvalisusprobleeme, eriti siis, kui sa kasutad kolmandatelt lehtedelt laetud pluginaid. Sellest hoiatusest hoolimata ei taga me plugina installeerimise edukust ega vastuta selle installeerimise tagajrjena phjustatud kahju eest. Teiste snadega - installeeri oma vastutusel. Lisaks on iga plugina paketi juures juhend, kuidas installeerida plugin ksitsi.',
    2 => 'Plug-ina installeerimise disklaimer',
    3 => 'Plugina installeerimisvorm',
    4 => 'Plugina fail',
    5 => 'Pluginate loetelu',
    6 => 'Hoiatus, plugin on juba installeeritud!',
    7 => 'Plugin, mida sa soovid installeerida, on juba installeeritud. Palun kustuta see plugin enne taasinstalleerimist.',
    8 => 'Plugina sobivuse kontroll  ebannestus',
    9 => 'See plugin vajab uuemat Geeklogi versiooni. Kas uuenda <a href="http://www.geeklog.net">Geeklog</a> vi hangi plugina sobiv versioon.',
    10 => "<br" . XHTML . "><b>Hetkel pole installeeritud htegi pluginat.</b>\n    <br" . XHTML . "><br" . XHTML . ">",
    11 => 'Plugina muutmiseks vi kustutamiseks klpsa allpool selle nimel. Sulle nidatakse plugina kohta tpsemat infot koos autori veebilehe aadressiga. Nidatakse nii installeeritud versiooni numbrit kui ka plugina koodist saadud plugina versioon. Selle phjal saad otsustada, kas plugin vajab uuendamist vi mitte. Plugina installeerimise vi uuendamise kohta loe tpsemalt plugina dokumentatsioonist.',
    12 => 'plugineditor () ei saanud plugina nime',
    13 => 'Plugina toimetaja',
    14 => 'Uus plugin',
    15 => 'Admin avaleht',
    16 => 'Plugina nimi',
    17 => 'Plugina versioon',
    18 => 'Geeklogi versioon',
    19 => 'Kasutuses',
    20 => 'Ja',
    21 => 'Ei',
    22 => 'Installeeri',
    23 => 'Salvesta',
    24 => 'Thista',
    25 => 'Kustuta',
    26 => 'Plugina nimi',
    27 => 'Plugina koduleht',
    28 => 'Installeeritud versioonid',
    29 => 'Geeklogi versioon',
    30 => 'Kustuta plugin?',
    31 => 'Kas sa oled kindel, et soovid  kustutada  selle plugina?  Jtkates kustutad sa ka kik selle pluginaga seotud andmed ja andmestruktuurid. Kui sa oled kindel, siis klpsa uuesti allpool "kustuta" nuppu.',
    32 => '<p><b>Viga: AutoLink silt on ebakorrektse formaadiga</b></p>',
    33 => 'Koodi versioon',
    34 => 'Uuenda',
    35 => 'Toimeta',
    36 => 'Kood',
    37 => 'andmed',
    38 => 'Uuenda!',
    39 => 'Lae plugin',
    40 => 'Sa vid otse siin laadida plugina arhiivi (.tar.gz, .tgz, .zip):',
    41 => 'Lae lesse',
    42 => 'Click to update',
    99 => 'Oli tundmatu viga',
    100 => 'OK.',
    101 => 'lesse laetud faili suurus letab php.ini failis oleva upload_max_filesize direktiivi.',
    102 => 'lesse laetud faili suurus letab HTML vormis mratud MAX_FILE_SIZE direktiivi.',
    103 => 'lesse laetud fail laeti lesse vaid osaliselt.',
    104 => 'Faili ei laetud lesse.',
    105 => '(defineerimata viga)',
    106 => 'Puudub temp kaust.',
    107 => 'Faili kettale kirjutamine ebannestus.',
    108 => 'Faili leslaadimine peatatud laienduse poolt.'
);

###############################################################################
# admin/syndication.php

$LANG33 = array(
    1 => 'loo lim',
    2 => 'salvesta',
    3 => 'kustuta',
    4 => 'thista',
    10 => 'Sisu jagamine',
    11 => 'Uus lim',
    12 => 'Admin avaleht',
    13 => 'Lime toimetamiseks vi kustutamiseks klpsa allpool selle nimel. Uue lime loomiseks klpsa Tee uus lalpool.',
    14 => 'Tiitel',
    15 => 'Tp',
    16 => 'Faili nimi',
    17 => 'Formaat',
    18 => 'viimati uuendatud',
    19 => 'Kasutuses',
    20 => 'Ja',
    21 => 'Ei',
    22 => '<i>(pole limi)</i>',
    23 => 'kik lood',
    24 => 'Lime toimetaja',
    25 => 'Lime tiitel',
    26 => 'Limiit',
    27 => 'Kannete pikkus',
    28 => '(0 = pole  teksti, 1 = tistekst, muu = piira antud mrkide arvuni.)',
    29 => 'Kirjeldus',
    30 => 'Viimane uuendus',
    31 => 'kooditabel',
    32 => 'Keel',
    33 => 'Sisu',
    34 => 'Kanded',
    35 => 'tundi',
    36 => 'Vali lime tp',
    37 => '',
    38 => 'Viga: puuduvad vljad',
    39 => 'Palun tida lime tiitli, kirjelduse ja faili nime vljad.',
    40 => 'Palun sisesta lugude  vi tundide arv.',
    41 => 'Sisesta',
    42 => '',
    43 => 'Igas rubriigis.',
    44 => 'Mitte heski.',
    45 => 'Rubriigi lehepises on link?',
    46 => 'Piira tulemused',
    47 => 'Otsi',
    48 => 'Toimeta',
    49 => 'Lime logo',
    50 => "Suhteline saidi urli suhtes ({$_CONF['site_url']})",
    51 => 'Sinu valitud limefailinimi on juba teise lime kasutuses. Palun vali teine nimi.',
    52 => 'Viga: failinimi on juba kasutusel',
    53 => 'Kik avalehe lood',
    54 => 'Valige loodava lime tp.',
    55 => 'Artiklid'
);

###############################################################################
# confirmation and error messages

$MESSAGE = array(
    1 => "Sinu salasna saadeti sulle E-postiga ja peaks kohe kohale judma. Palun jrgi kirjas olevaid juhiseid ja me tname sind {$_CONF['site_name']} lehe kasutamise eest",
    2 => "Tname sind {$_CONF['site_name']} lehele loo sisestamise eest. See saadeti meie meeskonnale kinnitamiseks. Prast meie lehe meeskonna poolset kinnitamist saavad kik seda meie lehel lugeda.",
    3 => '',
    4 => '',
    5 => 'Sinu konto info on edukalt salvestatud.',
    6 => 'Sinu eelistused on edukalt salvestatud.',
    7 => 'Sinu kommentaaride eelistused on edukalt salvestatud.',
    8 => 'Sa oled edukalt vlja logitud.',
    9 => 'Sinu lugu on edukalt salvestatud.',
    10 => 'Lugu on edukalt kustutatud.',
    11 => 'Sinu blokk on edukalt salvestatud.',
    12 => 'Blokk on edukalt kustutatud.',
    13 => 'Rubriik on edukalt salvestatud.',
    14 => 'Rubriik ja kik sellega seotud lood ja blokid on edukalt kustutatud.',
    15 => 'Your comment has been submitted for review and will be published when approved by a moderator.',
    16 => 'You have been unsubscribed. You will no longer be notified of new replies.',
    17 => '',
    18 => '',
    19 => '',
    20 => '',
    21 => 'Kasutaja on edukalt salvestatud.',
    22 => 'Kasutaja on edukalt kustutatud.',
    23 => '',
    24 => '',
    25 => '',
    26 => '',
    27 => 'Snum on edukalt saadetud.',
    28 => 'plugin on edukalt salvestatud',
    29 => 'Sorry, you do not have access to this administration page.  Please note that all attempts to access unauthorized features are logged',
    30 => 'Ligips tkestatud',
    31 => '',
    32 => '',
    33 => '',
    34 => '',
    35 => '',
    36 => '',
    37 => '',
    38 => '',
    39 => '',
    40 => 'Ssteemi teade',
    41 => '',
    42 => '',
    43 => '',
    44 => 'Plugin on edukalt installeeritud!',
    45 => 'Plugin on edukalt kustutatud.',
    46 => '',
    47 => 'Selliseid vimalusi saab kasutada vaid *nix keskkonnas. Kui ssteem ttab *nix operatsioonissteemis, siis puhvermlu on edukalt thjendatud. Kui operatsioonissteemiks on Windows, pead sa otsima faile nimekujuga adodb_*.php ja need failid ksitsi kustutama.',
    48 => "Tname sind oma liikmelisuse kinnitamise eest {$_CONF['site_name']} lehel. Meie meeskond vaatab sinu taotluse lbi. Kui see kinnitatakse, saadetakse sinu poolt antud E-postiaadressile E-kirjaga sinu salasna.",
    49 => 'Grupp on edukalt salvestatud.',
    50 => 'Grupp on edukalt kustutatud.',
    51 => 'See kasutajanimi on juba kasutuses. Palun vali mni teine.',
    52 => 'Sisestatud E-postiaadress tundub olevat ebakorrektne.',
    53 => 'Sinu uus salasna on aktsepteeritud. Palun logi uut salasna kasutades allpool oleva vormi kaudu sisse.',
    54 => 'Sinu tellimus uue salasna saamiseks on aegunud. Palun proovi alloleva vormi abil uuesti.',
    55 => 'Sulle saadeti E-kiri, mis peaks kohe sinu postkasti judma. Uue salasna mramiseks jrgi selles olevaid juhiseid.',
    56 => 'Sisestatud E-postiaadress on juba kasutuses teises kasutajakontos.',
    57 => 'Sinu kasutajakonto on edukalt kustutatud.',
    58 => 'Lim on edukalt salvestatud.',
    59 => 'Lim on edukalt kustutatud.',
    60 => 'Plugin on edukalt uuendatud.',
    61 => 'Plugin %s: Tundmatu teate jrjenumber',
    62 => 'Trackback kommentaar on kustutatud.',
    63 => 'Trackback kommentaari kustutamisel tekkis viga.',
    64 => 'Sinu trackback kommentaar on edukalt saadetud.',
    65 => 'Veebilogi kataloogi teenus on edukalt salvestatud.',
    66 => 'See Veebilogi kataloogi teenus on kustutatud.',
    67 => 'Uus salasna ei kattu kontrolliks sisestatud teise salasnaga!',
    68 => 'Sa pead sisestama praeguse kehtiva salasna.',
    69 => 'Sinu kasutajakonto on blokeeritud!',
    70 => 'Sinu konto ootab administraatori kinnitust.',
    71 => 'Sinu kasutajakonto loomise soov on nd kinnitatud ja ootab administraatoripoolset kinnitamist.',
    72 => 'Plugina installeerimisel tekkis viga. Tpsemalt vaata error.log failist.',
    73 => 'Plugina eemaldamisel tekkis viga. Tpsemalt vaata error.log failist.',
    74 => 'Pingback on edukalt saadetud.',
    75 => 'Trackbackid tuleb saata post meetodiga.',
    76 => 'Kas sa testi soovid selle kustutada?',
    77 => 'Hoiatus: <br' . XHTML . '>sa mrasid vaikekooditabeliks UTF-8, kuid sinu server ei toeta mitmebaidilist kooditabelit. Palun installeeri PHP jaoks mbstring funktsioonid vi vali mni teine kooditabel/keel.',
    78 => 'Palun kontrolli, et E-postiaadress ja kontrolliks sisestatud E-postiaadress oleksid samad.',
    79 => 'Leht, mida soovid avada, vajab tks funktsiooni, mida kahjuks sellel saidil enam kasutuses ei ole.',
    80 => 'Selle lime teinud plugina t on hetkel vlja llitatud. Sa ei saa seda lime toimetada enne kui oled antud plugina uuesti tle llitanud.',
    81 => 'Vimalik, et sa kirjutasid oma sisselogimisinfo valesti. Palun proovi alloleva vormi abil  uuesti sisse logida.',
    82 => 'Sa oled letanud lubatud sisselogimiskatsete limiidi. Palun proovi hiljem uuesti.',
    83 => 'Et muuta oma salasna, E-postiaadressi vi kui kaua peaks sait sind mletama, pead sa sisestama oma kehtiva salasna.',
    84 => 'Oma konto kustutamiseks sisesta oma kehtiv salasna.',
    85 => 'E-kirja saatmisel oli trge.',
    86 => 'OpenID server lkkas teie sisselogimiskatse tagasi.',
    87 => 'OpenID sisselogimine thistati kasutaja poolt.',
    88 => 'OpenID server  andis veateate.',
    89 => 'Ei suuda leida antud identiteedi URL-i OpenID serverit.',
    90 => 'OpenID tuvastamine thistatud.',
    91 => 'Sa mrasid vigase identiteedi URL-i.',
    92 => "Palun <a href=\"{$_CONF['site_admin_url']}/sectest.php\">kontrolli enne oma lehe kasutama hakkamist selle turvalisust!</a>",
    93 => 'Andmebaasi varundamine oli edukas.',
    94 => 'Varundamine ebannestus: faili suurus on alla 1kb',
    95 => 'Oli viga.',
    96 => '',
    97 => '',
    98 => 'Plugina lesse laadimine oli edukas.',
    99 => 'Plugin on juba olemas.',
    100 => 'Laetud plugina fail pole GZip vi Zip formaadis tihendatud arhiiv.',
    101 => 'Pole htegi rubriiki, millele sul oleks ligipsu. Sul peab olema vhemalt ks rubriik, et saaksid lugusid sisestada.',
    400 => 'Kik vljad ei lbinud kontrolli',
    401 => 'Palun sisesta tisnimi'
);

###############################################################################

$LANG_ACCESS = array(
    'access' => 'Ligips',
    'ownerroot' => 'omanik (root)',
    'group' => 'Grupp',
    'readonly' => 'Ainult loetav',
    'accessrights' => 'Ligipsuigused',
    'owner' => 'Omanik',
    'grantgrouplabel' => 'Grant Above Group Edit Rights',
    'permmsg' => 'Mrkus: liikmed on kik lehele sisse loginud lehe kasutajad ja anonmsed on kik lehel olevad ja mitte sisse loginud lehe lugejad.',
    'securitygroups' => 'Turvalisusgrupid',
    'editrootmsg' => "Kuigi sa oled kasutajate administraator, ei saa sa muuta root kasutajate andmeid, kui sa ei ole ise root kasutaja. Sa vid toimetada kiki teisi kasutajaid, vlja arvatud root kasutajaid. Pane thele, et kik igustamata katsed muuta root kasutajate andmeid logitakse.  Palun mine tagasi <a href=\"{$_CONF['site_admin_url']}/user.php\">Kasutajate administreerimislehele. </a>",
    'securitygroupsmsg' => 'Mrgi grupid, millesse soovid, et see kasutaja kuuluks.',
    'groupeditor' => 'Grupi toimetaja',
    'description' => 'Kirjeldus',
    'name' => 'Nimi',
    'rights' => 'igused',
    'missingfields' => 'Puuduvad vljad',
    'missingfieldsmsg' => 'Sa pead grupi jaoks sisestama grupi nime ja kirjelduse',
    'groupmanager' => 'Grupi haldur',
    'newgroupmsg' => 'Grupi toimetamiseks vi kustutamiseks klpsa selle nimel allpool. Uue grupi loomiseks klpsa Tee uus lal. Pane thele, et phigruppe (core group) ei saa kustutada, sest need on ssteemis kasutusel.',
    'groupname' => 'Grupi nimi',
    'coregroup' => 'Phigrupp',
    'yes' => 'Ja',
    'no' => 'Ei',
    'corerightsdescr' => "See grupp on {$_CONF['site_name']} phigrupp (Core Group).  Seetttu selle grupi igusi ei saa muuta. Allpool on ainult loetaval kujul loetelu antud grupi igustest.",
    'groupmsg' => 'Sellel lehel on turvalisusgrupid hierarhilised.  Lisades antud grupi mnda alloleva grupi koosseisu, annad sa antud grupile samad igused kui neilgi gruppidel. On eelistatavam kasutada allolevaid gruppe antud grupile iguste mramisel.  Kui vajad kohandatud igustega gruppi, siis saad sa selle lehe "igused" osas mrata mitmeid igusi. iguste mramiseks mrgi lihtsalt vastava grupi vi iguse juures olev mrkeruut.',
    'coregroupmsg' => "See grupp on {$_CONF['site_name']} phigrupp (Core Group).  Seetttu ei saa selle grupi kuulumist teistesse gruppidesse muuta. Allpool on ainult loetaval kujul loetelu gruppidest, kuhu see grupp kuulub.",
    'rightsdescr' => 'Grupile vib mrata igusi otse, mrates neid just antud grupile,  vi andes vastavad igused mnele neist gruppidest, kuhu antud grupp kuulub. Need igused, mis on ilma mrkeruuduta, on antud grupile juba mratud nende gruppide kaudu, kuhu see hetkel kuulub. Neid igusi, mille krval on mrkeruut, vib mrata otse antud grupile.',
    'lock' => 'Lukk',
    'members' => 'Liikmed',
    'anonymous' => 'Anonmne',
    'permissions' => 'Lubatud',
    'permissionskey' => 'R =lugemis-, E = toimetamis-, toimetamisigus annab ka  lugemisiguse',
    'edit' => 'Toimeta',
    'none' => 'Mitte midagi',
    'accessdenied' => 'Ligips tkestatud',
    'storydenialmsg' => "Sul ei ole igust seda lugu vaadata. Selle phjuseks vib olla, et sa ei ole {$_CONF['site_name']} lehel registreerunud kasutaja.  Palun <a href=\"users.php?mode=new\"> registreeru {$_CONF['site_name']} lehe kasutajaks </a>, et saada kiki registreerunud kasutaja igusi",
    'nogroupsforcoregroup' => 'See grupp ei kuulu htegi teise gruppi',
    'grouphasnorights' => 'Sellel grupil pole ligipsu helegi administreerimisfunktsioonile antud saidil',
    'newgroup' => 'Uus grupp',
    'adminhome' => 'Admin avaleht',
    'save' => 'salvesta',
    'cancel' => 'thista',
    'delete' => 'kustuta',
    'canteditroot' => 'Sa ritasid toimetada root gruppi, kuid sa pole ise root grupi liige. Selletttu tkestati sinu ligips antud grupile. Kui sa arvad, et tegu on veaga, siis palun kontakteeru lehe administraatoriga.',
    'listusers' => 'Nita kasutajad',
    'listthem' => 'loetelu',
    'usersingroup' => 'Kasutajad grupis "%s"',
    'usergroupadmin' => 'Kasutajagrupi administreerimine',
    'add' => 'Lisa',
    'remove' => 'Eemalda',
    'availmembers' => 'Vimalikud liikmed',
    'groupmembers' => 'Grupi liikmed',
    'canteditgroup' => 'Grupi toimetamiseks pead sa ise olema selle grupi liige. Kui arvad, et tegu on veaga, siis palun kontakteeru lehe administraatoriga.',
    'cantlistgroup' => 'Grupi liikmete ngemiseks pead sa ise olema selle grupi liige. Kui sa arvad, et tegu on veaga, palun kontakteeru lehe administraatoriga.',
    'editgroupmsg' => 'Grupi liikmeskonna muutmiseks klpsa kasutaja nimel ja kasuta kas Lisa vi Eemalda nuppu. Kui kasutaja on grupi liige, on tema nimi ainult parempoolses loetelus. Kui oled lpetanud, klpsa grupi koosseisu uuendamiseks ja gruppide haldamise pealehele judmiseks <b>Salvesta</b> nuppu.',
    'listgroupmsg' => 'Loetelu kigist grupi <b>%s</b> hetke liikmetest:',
    'search' => 'Otsi',
    'submit' => 'Sisesta',
    'limitresults' => 'Piira tulemused',
    'group_id' => 'Grupi ID',
    'plugin_access_denied_msg' => 'Sa ritasid ligi pseda pluginate administreerimislehele, milleks polnud sul igust. Pane thele, et kik igustamata katsed sellele lehele ligi pseda logitakse.',
    'groupexists' => 'Grupi nimi on juba olemas',
    'groupexistsmsg' => 'Sama nimega grupp on juba olemas. Grupi nimed peavad olema ksteisest erinevad.'
);

###############################################################################
# admin/database.php

$LANG_DB_BACKUP = array(
    'last_ten_backups' => 'Viimased 10 varundamist',
    'do_backup' => 'Varunda',
    'backup_successful' => 'Andmebaasi varundamine oli edukas.',
    'db_explanation' => 'Sinu Geeklogist uue varukoopia tegemiseks klpsa allolevat nuppu',
    'not_found' => "Ebakorrektne tee programmini, kasutusel turvapiirang  vi mysqldump pole kivitatav.<br" . XHTML . ">\n    Kontrolli seadistuses <strong>mysqldump_path</strong> definitsiooni.<br" . XHTML . ">\n    Kontrolli <a href=\"http://www.php.net/manual/en/features.safe-mode.php#ini.open-basedir\">open_basedir</a>\nPHP seadistust.<br" . XHTML . ">  \n    Hetkel on muutuja vrtuseks: <var>{$_DB_mysqldump_path}</var>",
    'zero_size' => 'Varundamine ebannestus, faili suurus on 0 baiti',
    'path_not_found' => "{$_CONF['backup_path']} pole olemas vi pole kataloog.",
    'no_access' => "Viga: varunduskataloog, {$_CONF['backup_path']}, pole ligipsetav.",
    'backup_file' => 'Varundusfail',
    'size' => 'suurus',
    'bytes' => 'baiti',
    'total_number' => 'Varunduste ldarv: %d',
    'download' => 'Klpsa selle faili allalaadimiseks',
    'new_backup' => 'Uus varundamine',
    'delete_failure' => 'he vi enama backupfaili kustutamine ebannestus.',
    'delete_success' => 'Backupfail(id) on edukalt kustutatud.',
    'convert_menu' => 'Konverteeri InnoDB formaati',
    'convert_title' => 'Konverteeri InnoDB tabeliteks',
    'convert_button' => 'Konverteeri',
    'sorry_no_innodb' => 'Kahjuks sinu MySQL-i versioon ei toeta  InnoDB tabeleid.',
    'innodb_explain' => 'InnoDB tabelid pakuvad suuremat judlust, kui tegu on <em>testi</em> suure andmebaasiga, kuid teeb varundamise protsessi keerulisemaks. Palun <a href="http://dev.mysql.com/doc/mysql/en/innodb.html">loe rohkem </a> InnoDB tabelite kohta kivate poolt ja vastuargumente, enne kui teostad selle operatsiooni.',
    'already_converted' => 'Mrkus: Nib, et kik tabelid on juba konverteeritud InnoDB tabeliteks.',
    'conversion_patience' => 'Mrkus: Konverteerimine vib vtta aega. Palun kannatust.',
    'innodb_success' => 'Tabelid on edukalt konverteeritud InnoDB formaati.',
    'table_issues' => 'Mnede tabelitega vis olla probleeme. Vaata tpsemat infot error.log failist. .',
    'optimize_menu' => 'Optimeeri tabeleid',
    'optimize_title' => 'Optimeeri tabeleid',
    'optimize_button' => 'Optimeeri',
    'optimize_explain' => 'Tabelite optimeerimine vib parandada saidi judlust. Tegelik kasu sltub iga tabeli kasutusest ja mnede tabelite puhul annab see rohkem kasu kui teiste puhul. ra oota teliselt suurt judluse tusu. <a href="http://dev.mysql.com/doc/mysql/en/optimize-table.html">MySQL manuaal </a> tleb: <q>Ei ole tenoline, et sa peaksid seda tegema sagedamini kui korra kuus vi ndalas</q>.',
    'last_optimization' => 'Viimane optimeerimine',
    'optimization_patience' => 'Mrkus: Optimeerimine vib vtta aega. Palun kannatust.',
    'optimize_success' => 'Andmebaasi tabelite optimeerimine oli edukas.'
);

###############################################################################

$LANG_BUTTONS = array(
    1 => 'Avaleht',
    2 => 'Kontakt',
    3 => 'Avalda',
    4 => '',
    5 => '',
    6 => '',
    7 => 'Lehe statistika',
    8 => 'Kohanda',
    9 => 'Otsi',
    10 => 'tpsem otsing',
    11 => 'Artiklid'
);

###############################################################################
# 404.php

$LANG_404 = array(
    1 => 'Viga/Error 404',
    2 => 'Ma otsisin igalt poolt, kuid ei leidnud otsitud lehte: <b>%s</b>.',
    3 => "<p>Mul on kahju, kuid soovitud  faili ei ole. Palun vaata kindlasti <a href=\"{$_CONF['site_url']}\">pealehele </a> vi <a href=\"{$_CONF['site_url']}/search.php\">otsimislehele,</a> et otsitavat leida."
);

###############################################################################
# login form

$LANG_LOGIN = array(
    1 => 'Nutav sisselogimine',
    2 => 'Selle lehe osa vaatamiseks pead kasutajana sisse logima.',
    3 => 'Logi sisse',
    4 => 'Uus kasutaja'
);

###############################################################################
# trackback.php

$LANG_TRB = array(
    'trackback' => 'Trackback',
    'from' => 'kust',
    'tracked_on' => 'Kommenteeritud',
    'read_more' => '[loe lisaks]',
    'intro_text' => 'Siin on see, mida teised tlevad "%s" kohta:',
    'no_comments' => 'Selle sisestuse kohta pole trackbackkommentaare.',
    'this_trackback_url' => 'Selle sisestuse trackback URL:',
    'num_comments' => '%d trackbackkommentaari',
    'send_trackback' => 'Saada Ping',
    'preview' => 'Eelvaade',
    'editor_title' => 'Saada trackbackkommentaar',
    'trackback_url' => 'Trackbacki URL',
    'entry_url' => 'Sisestuse URL',
    'entry_title' => 'Sisestuse tiitel',
    'blog_name' => 'Saidi nimi',
    'excerpt' => 'katkend',
    'truncate_warning' => 'Mrkus: vastuvttev leht vib sinu katkendit lhendada.',
    'button_send' => 'Saada',
    'button_preview' => 'Eelvaade',
    'send_error' => 'Viga',
    'send_error_details' => 'Viga trackbackkommentaari saatmisel:',
    'url_missing' => 'Puudub sisestuse URL',
    'url_required' => 'Palun kirjuta sisestuse jaoks vhemalt URL.',
    'target_missing' => 'Pole Trackback URL-i',
    'target_required' => 'Palun kirjuta trackbacki URL',
    'error_socket' => 'Ei saanud avada vratit.',
    'error_response' => 'Serveri vastus oli arusaamatu.',
    'error_unspecified' => 'Mratlemata viga.',
    'select_url' => 'Vali trackbacki URL',
    'not_found' => 'Ei leidnud trackback URL-i',
    'autodetect_failed' => 'Geeklog ei suutnud tuvastada saadetava kommentaari jaoks trackback URL-i. Palun kirjuta see ksitsi allolevasse vormi.',
    'trackback_explain' => 'Vali allolevast loetelust link, kuhu soovid oma trackback kommentaari saata. Prast seda ritab Geeklog tuvastada trackback kommentaari jaoks ige URL-i. Kui sa tead iget URL-i, vid sa <a href="%s">sisestada selle ksitsi. </a>',
    'no_links_trackback' => 'Ei leidnud linke. Sa ei saa selle sisestuse kohta saata trackback kommentaari.',
    'pingback' => 'Pingback',
    'pingback_results' => 'Pingback tulemused',
    'send_pings' => 'Saada Ping-id',
    'send_pings_for' => 'Saada Ping-id "%s"',
    'no_links_pingback' => 'Ei leidnud linke. Selle sisestuse kohta ei saadetud  pingbacke.',
    'pingback_success' => 'Pingback on saadetud.',
    'no_pingback_url' => 'Ei leidnud pingback URL-i.',
    'resend' => 'Saada uuesti',
    'ping_all_explain' => 'Sa vid teavitada lehti, millele sinu leht viitab saates (<a href="http://en.wikipedia.org/wiki/Pingback"> Pingbacki</a>), teavitada lehe uuendamisest saates pingi veebi logikataloogidesse (weblog directory) vi saata <a href="http://en.wikipedia.org/wiki/Trackback"> Trackbackkommentaari,</a> viimast juhul, kui oled oma lehel kommenteerinud mnel teisel saidil olnud kellegi teise kirjutist.',
    'pingback_button' => 'Saada Pingback',
    'pingback_short' => 'Saada pingback kigile kesolevalt  lehelt lingitud lehtedele.',
    'pingback_disabled' => '(Pingback on vlja llitatud)',
    'ping_button' => 'Saada Ping',
    'ping_short' => 'Pingi veebi logikatalooge',
    'ping_disabled' => '(Ping on vlja llitatud)',
    'trackback_button' => 'Saada Trackback',
    'trackback_short' => 'Saada trackbackkommentaar.',
    'trackback_disabled' => '(Trackback on vlja llitatud)',
    'may_take_a_while' => 'Pane thele, et pingi ja pingbacki saatmine vib vtta aega.',
    'ping_results' => 'Ping tulemused',
    'unknown_method' => 'Tundmatu ping meetod',
    'ping_success' => 'Ping on saadetud.',
    'error_site_name' => 'Palun kirjuta saidi nimi.',
    'error_site_url' => 'Palun sisesta lehe URL.',
    'error_ping_url' => 'Palun kirjuta toimiv ping URL.',
    'no_services' => 'Pole hlestatud veebi logikataloogide kasutamine (weblog directory services).',
    'services_headline' => 'Veebi logikataloogide teenused',
    'service_explain' => 'Veebi logikataloogi teenusepakkuja andmete toimetamiseks klpsa allpool vastavat nuppu logikataloogi nime krval. Uue logikataloogi lisamiseks klpsa Tee uus lal.',
    'service' => 'Teenus',
    'ping_method' => 'Ping meetod',
    'service_website' => 'Veebileht',
    'service_ping_url' => 'Pingi URL',
    'ping_standard' => 'Standard Ping',
    'ping_extended' => 'Laiendatud ping',
    'ping_unknown' => '(tundmatu meetod)',
    'edit_service' => 'Toimeta veebi logikataloogi andmeid',
    'trackbacks' => 'Trackbackid',
    'editor_intro' => 'Valmista oma trackbackkommentaar  <a href="%s">%s jaoks ette</a>.',
    'editor_intro_none' => 'Valmista trackback kommentaar ette.',
    'trackback_note' => 'Trackbackkommentaari saatmiseks mine lugude loetelusse ja klpsa loo juures "". Klpsa jrgmisel lingil, et <a href="%s"> saata lugudega sidumata trackbackkommentaari.</a>',
    'pingback_explain' => 'Kirjuta URL, kuhu pingback saata. Pingback viitab tagasi sinu saidi pealehele.',
    'pingback_url' => 'Pingbacki URL',
    'site_url' => 'Antud saidi URL',
    'pingback_note' => 'Pingbacki saatmiseks mine lugude loetelusse ja klpsa loo juures "". Klpsa jrgmisel lingil, et <a href="%s"> saata lugudega sidumata pingbacki.</a>',
    'pbtarget_missing' => 'Pole pingbacki URL-i',
    'pbtarget_required' => 'Palun kirjuta pingbacki URL',
    'pb_error_details' => 'Pingbacki saatmisel tekkis viga:',
    'delete_trackback' => 'Selle trackbacki kustutamiseks klpsa: '
);

###############################################################################
# directory.php

$LANG_DIR = array(
    'title' => 'Artiklite kataloog',
    'title_year' => '%d artiklid',
    'title_month_year' => '%s %d artiklid',
    'nav_top' => 'Tagasi peakataloogi',
    'no_articles' => 'Pole artikleid'
);

###############################################################################
# admin/sectest.php

$LANG_SECTEST = array(
    'sectest' => 'Geeklogi turvalisuse kontroll',
    'results' => 'Turvalisuse kontrolli tulemused',
    'okay' => 'Kik nib korras olevat.',
    'please_fix' => 'Palun paranda lal toodud probleemid, enne kui vtad oma saidi kasutusele!',
    'please_note' => 'Palun pane thele, et sait ei ole kunagi 100 protsenti turvaline. See skript testib ainult ilmseid turvaprobleeme.',
    'stay_informed' => 'Et olla informeeritud Geeklogi uutest versioonidest ja vimalikest turvaprobleemidest, soovitame me  et sa liituksid (vikese liiklusega) %s meililistiga ja/vi kasutad %s, mis asub lehe Admin mens, et aeg-ajalt kontrollida uue versiooni olemasolu.',
    'public_html' => '"public_html" ei tohiks kunagi olla osa  sinu saidi URList.  Palun loe public_html kohta kivat osa %s uuesti ja muuda enne jtkamist vastavalt lehe seadistust.',
    'installation' => 'Installeerimisjuhised',
    'directory' => 'Kaust',
    'failed_tmp' => 'Failed to create a temporary file in your %s directory. Check your directory permissions!',
    'fix_it' => 'See on turvarisk ja see tuleb parandada!',
    'reachable' => 'Sinu %s on veebist kttesaadav.',
    'not_reachable' => 'Hea! Sinu %s pole veebist kttesaadav.',
    'not_sure' => 'Sain HTTP vastuskoodi %s, kui proovisin testida %s. Ma ei tea, mida sellega teha ...',
    'remove_inst' => 'Sa peaksid testi eemaldama prast lehe veavabalt tlesaamist installkausta %s.',
    'remove_inst2' => 'Selle alles jtmine jtab pahatahtlikel kasutajatel vimaluse hvitada sinu praegune install, vtta sinu leht le vi hankida tundlikku infot.',
    'inst_removed' => 'Hea! Nib,  et oled juba install kausta eemaldanud.',
    'fix_password' => 'Sa ei ole veel muutnud <strong>vaike salasna</strong> "password" %s root kontol r (del).',
    'password_okay' => 'Hea! Nib, et sa oled juba muutnud Root konto vaikesalasna.'
);

###############################################################################
# "What's New" Time Strings
# 
# For the first two strings, you can use the following placeholders.
# Order them so it makes sense in your language:
# %i    item, "Stories"
# %n    amount, "2", "20" etc.
# %t    time, "2" (weeks)
# %s    scale, "hrs", "weeks"

$LANG_WHATSNEW = array(
    'new_string' => '%n uut %i viimase %t %s jooksul',
    'new_last' => ' viimase %t %s jooksul',
    'minutes' => 'minuti',
    'hours' => 'tunni',
    'days' => 'peva',
    'weeks' => 'ndala',
    'months' => 'kuu',
    'minute' => 'minut',
    'hour' => 'tund',
    'day' => 'peva',
    'week' => 'ndala',
    'month' => 'kuu'
);

###############################################################################
# Month names

$LANG_MONTH = array(
    1 => 'Jaanuar',
    2 => 'Veebruar',
    3 => 'Mrts',
    4 => 'Aprill',
    5 => 'Mai',
    6 => 'Juuni',
    7 => 'Juuli',
    8 => 'August',
    9 => 'September',
    10 => 'Oktoober',
    11 => 'November',
    12 => 'Detsember'
);

###############################################################################
# Weekdays

$LANG_WEEK = array(
    1 => 'Phapev',
    2 => 'Esmaspev',
    3 => 'Teisipev',
    4 => 'Kolmapev',
    5 => 'Neljapev',
    6 => 'Reede',
    7 => 'Laupev'
);

###############################################################################
# Admin - Strings
# 
# These are some standard strings used by core functions as well as plugins to
# display administration lists and edit pages

$LANG_ADMIN = array(
    'search' => 'Otsi',
    'limit_results' => 'Piira tulemused',
    'submit' => 'Valmis',
    'edit' => 'Toimeta',
    'edit_adv' => 'Toimeta lisa',
    'admin_home' => 'Admin avaleht',
    'create_new' => 'Tee uus',
    'create_new_adv' => 'Tee uus (lisa)',
    'enabled' => 'Kasutuses',
    'title' => 'Tiitel',
    'type' => 'Tp',
    'topic' => 'Rubriik',
    'help_url' => 'Abifaili URL',
    'save' => 'Salvesta',
    'cancel' => 'Thista',
    'delete' => 'Kustuta',
    'delete_sel' => 'Kustuta valitud',
    'copy' => 'Koopia',
    'no_results' => '- Ei leidnud midagi -',
    'data_error' => 'Liitumiste andmetega tekkis viga. Palun kontrolli algandmeid.',
    'preview' => 'Eelvaade',
    'records_found' => 'Leitud kirjed',
    'addchild' => 'Lisa alamdetail',
    'list' => 'Loetelu',
    'list_all' => 'Loetle kik',
    'meta_description' => 'Meta kirjeldus',
    'meta_keywords' => 'Meta mrksnad',
    'na' => 'N/A',
    'token_expiry' => 'Sul on aega kuni %s, et teha muutusi. Prast seda aegub lehele lisatud turvalisuskood ja tehtud muutused lhevad kaotsi.'
);

# Localisation of the texts for the various drop-down menus that are actually
# stored in the database. If these exist, they override the texts from the
# database.

$LANG_commentcodes = array(
    0 => 'On kommentaarid',
    -1 => 'Pole kommentaare',
    1 => 'Kommenteerimine suletud'
);

$LANG_commentmodes = array(
    'flat' => 'lihtne',
    'nested' => 'ksteise sees',
    'threaded' => 'Limedena',
    'nocomment' => 'pole kommentaare'
);

$LANG_cookiecodes = array(
    0 => 'ra mleta',
    3600 => '1 tund',
    7200 => '2 tundi',
    10800 => '3 tundi',
    28800 => '8 tundi',
    86400 => '1 pev',
    604800 => '1 ndal',
    2678400 => '1 kuu'
);

$LANG_dateformats = array(
    0 => 'Ssteemi seadistus'
);

$LANG_featurecodes = array(
    0 => 'Pole pealugu',
    1 => 'Pealugu'
);

$LANG_frontpagecodes = array(
    0 => 'Ainult rubriigis',
    1 => 'Avalehel ja rubriigis'
);

$LANG_postmodes = array(
    'plaintext' => 'Puhas tekst',
    'html' => 'HTML kujundusega'
);

$LANG_sortcodes = array(
    'ASC' => 'Vanemad enne',
    'DESC' => 'Uuemad enne'
);

$LANG_trackbackcodes = array(
    0 => 'Trackback lubatud',
    -1 => 'Trackback keelatud'
);

###############################################################################
# Localization of the Admin Configuration UI

$LANG_CONFIG = array(
    'home' => 'Avaleht',
    'admin_home' => 'Admin avaleht',
    'sections' => 'Seadistuse alajaotused',
    'restore' => 'Taasta',
    'add_element' => 'Lisa element',
    'save_changes' => 'Salvesta muudatused',
    'reset_form' => 'Reseti vorm',
    'changes_made' => 'Muudatused tehti edukalt',
    'title' => 'Seadistuste haldaja',
    'disable' => 'Klpsa antud valiku keelamiseks',
    'enable' => 'Luba'
);

$LANG_configsections['Core'] = array(
    'label' => 'Geeklog',
    'title' => 'Geeklog seadistus'
);

$LANG_confignames['Core'] = array(
    'path_html' => 'HTML asukoht',
    'site_url' => 'Lehe URL',
    'site_admin_url' => 'Administreerimise URL',
    'site_mail' => 'Lehe E-post',
    'noreply_mail' => 'mitte-vastatav E-post',
    'site_name' => 'Lehe Nimi',
    'site_slogan' => 'Deviis',
    'microsummary_short' => 'Mikrokokkuvtte',
    'path_log' => 'Logi',
    'path_language' => 'Keel',
    'backup_path' => 'Varundus',
    'path_data' => 'Andmed',
    'path_images' => 'Pildid',
    'path_pear' => 'Pear asukoht',
    'have_pear' => 'Pear olemas?',
    'mail_settings' => 'E-posti hlestus',
    'allow_mysqldump' => 'Luba MySQL Dump',
    'mysqldump_path' => 'programmi asukoht',
    'mysqldump_options' => 'MySQL Dump valikud',
    'mysqldump_filename_mask' => 'Bakkup faili nime mall',
    'theme' => 'Skeem',
    'doctype' => 'DOCTYPE Deklaratsioon',
    'menu_elements' => 'Men elemendid',
    'path_themes' => 'Skeemide asukoht',
    'disable_new_user_registration' => 'Keela uue kasutaja registreerimine',
    'allow_user_themes' => 'Luba kasutaja skeem',
    'allow_user_language' => 'Luba kasutaja keel',
    'allow_user_photo' => 'Luba kasutaja foto',
    'allow_username_change' => 'Luba kasutajanime muutmine',
    'allow_account_delete' => 'Luba konto kustutamine',
    'hide_author_exclusion' => 'Luba autori peitmine',
    'show_fullname' => 'Nita tisnimi',
    'show_servicename' => 'Nita teenusenimi',
    'custom_registration' => 'Luba kohandatud registreerimine',
    'user_login_method' => 'Kasutaja sisselogimise meetod',
    'spamx' => 'Spam-X tegevused',
    'sort_admin' => 'Sordi lingid',
    'language' => 'Keel',
    'locale' => 'Asukoht',
    'date' => 'Kuupevaformaat',
    'daytime' => 'Kellaaja formaat',
    'shortdate' => 'Lhike kuupevaformaat',
    'dateonly' => 'Ainult kuupeva formaat',
    'timeonly' => 'Ainult aja formaat',
    'week_start' => 'Ndal algab',
    'hour_mode' => 'Tundide nitamine',
    'thousand_separator' => 'Tuhande eraldaja',
    'decimal_separator' => 'Kmnendkoha eraldaja',
    'decimal_count' => 'Kmnendkohti',
    'language_files' => 'Keelefailid',
    'languages' => 'Keeled',
    'timezone' => 'Ajavnd',
    'site_disabled_msg' => 'Leht suletud, teade vi URL',
    'rootdebug' => 'Root Debugimine',
    'cookie_session' => 'Sessioonikpsise nimi ',
    'cookie_name' => 'Psikpsise nimi',
    'cookie_password' => 'Salasnakpsise nimi',
    'cookie_theme' => 'Skeemikpsise nimi',
    'cookie_language' => 'Keelekpsise nimi',
    'cookie_tzid' => 'Ajavndikpsise nimi',
    'cookie_anon_name' => 'Anon. kasutajanime kpsise nimi',
    'cookie_ip' => 'Kpsistes on IP?',
    'default_perm_cookie_timeout' => 'Psiv kehtivusaeg',
    'session_cookie_timeout' => 'Sessiooni kehtivusaeg',
    'cookie_path' => 'Kpsise tee',
    'cookiedomain' => 'Kpsise domeen',
    'cookiesecure' => 'Turvahenduse kpsis',
    'lastlogin' => 'Salvestan viimatise logimise aja?',
    'num_search_results' => 'Otsingutulemuste arv',
    'loginrequired' => 'Vajab sisselogimist?',
    'submitloginrequired' => 'Sisestamine vajab sisselogimist?',
    'commentsloginrequired' => 'Kommenteerimine vajab sisselogimist?',
    'statsloginrequired' => 'Statistika vajab sisselogimist?',
    'searchloginrequired' => 'Otsimine vajab sisselogimist?',
    'profileloginrequired' => 'Profiil vajab sisselogimist?',
    'emailuserloginrequired' => 'Kasutajale kirjutamine vajab sisselogimist?',
    'emailstoryloginrequired' => 'Loo saatmine vajab sisselogimist?',
    'directoryloginrequired' => 'Artiklikaust vajab sisselogimist?',
    'storysubmission' => 'Loo sisestuste puhver?',
    'usersubmission' => 'Kasutajate sisestuste puhver?',
    'listdraftstories' => 'Loetle mustandlugusi?',
    'notification' => 'Teavitamine',
    'postmode' => 'Vaikimisi postitusviis',
    'speedlimit' => 'Postituse kiiruspiir',
    'skip_preview' => 'Jta postitamisel eelvaade vahele',
    'advanced_editor' => 'Keerukam toimetaja?',
    'wikitext_editor' => 'Wikitekst toimetaja?',
    'cron_schedule_interval' => 'Cron ajaplaani intervall',
    'sortmethod' => 'Sorteeri rubriike',
    'showstorycount' => 'Nitan lugude arvu?',
    'showsubmissioncount' => 'Nitan sisestuste arvu?',
    'hide_home_link' => 'Avalehe link peidetud?',
    'whosonline_threshold' => 'Sessiooni pikkus',
    'whosonline_anonymous' => 'Anonmsed ei ne nimesid?',
    'emailstories' => 'Pevased kokkuvtted lubatud?',
    'emailstorieslength' => 'Lugude pikkus',
    'emailstoriesperdefault' => 'Lubatud uute kasutajate jaoks?',
    'allow_domains' => 'Automaatselt luba domeenid',
    'disallow_domains' => 'Automaatselt keela domeenid',
    'newstoriesinterval' => 'Uute lugude intervall',
    'newcommentsinterval' => 'Uute kommentaaride intervall',
    'newtrackbackinterval' => 'Uute trackbackide intervall',
    'hidenewstories' => 'Peida uued lood',
    'hidenewcomments' => 'Peida uued kommentaarid',
    'hidenewtrackbacks' => 'Peida uued trackbackid',
    'hidenewplugins' => 'Peida pluginate uued kanded',
    'title_trim_length' => 'Pealkirjade maksimaalne pikkus',
    'trackback_enabled' => 'Trackback lubatud?',
    'pingback_enabled' => 'Pingback lubatud?',
    'ping_enabled' => 'Ping lubatud?',
    'trackback_code' => 'Vaikimisi Trackback',
    'multiple_trackbacks' => 'Multi-Trackback',
    'trackbackspeedlimit' => 'Trackbacki kiirusepiirang',
    'check_trackback_link' => 'Kontrolli Trackbacke',
    'pingback_self' => 'Pingbacki ennast?',
    'pingback_excerpt' => 'Loo Pingbacki vljavte?',
    'link_documentation' => 'Link dokumentatsioonile?',
    'link_versionchecker' => 'Link versioonikontrollijale?',
    'maximagesperarticle' => 'Piltide maksimum loo kohta',
    'limitnews' => 'Lugusid lehel',
    'minnews' => 'Min. lugusid lehel',
    'contributedbyline' => '"Nita postitajat?"',
    'hideviewscount' => 'Peida vaatamiste arv',
    'hideemailicon' => 'Peida link E-post?',
    'hideprintericon' => 'Peida link prindi?',
    'allow_page_breaks' => 'Luba lehekljevahetused?',
    'page_break_comments' => 'Kommentaarid mitmelehelistes lugudes',
    'article_image_align' => 'Rubriigi ikooni joondus',
    'show_topic_icon' => 'Nita rubriigi ikooni?',
    'draft_flag' => 'Vaikimisi mustandilipp',
    'frontpage' => 'Vaikimisi avalehel',
    'hide_no_news_msg' => 'Peida teade "Pole uudiseid"?',
    'hide_main_page_navigation' => 'Peida Main Page Navigation?',
    'onlyrootfeatures' => 'Ainult root saab pealugu mrata?',
    'aftersave_story' => 'Prast loo salvestamist',
    'aftersave_user' => 'Prast kasutaja salvestamist',
    'show_right_blocks' => 'Nita alati paremblokki?',
    'showfirstasfeatured' => 'Nita esimest lugu pealoona?',
    'backend' => 'Luba limed?',
    'rdf_file' => 'Limede vljundkaust',
    'rdf_limit' => 'Limede limiit',
    'rdf_storytext' => 'Lugude pikkus limedes',
    'rdf_language' => 'Lime keel',
    'syndication_max_headlines' => 'Maks. pealkirju limedes (portaalblokid)',
    'copyrightyear' => 'autorikaitse aasta',
    'image_lib' => 'pilditeek',
    'path_to_mogrify' => 'Mogrify asukoht',
    'path_to_netpbm' => 'Netpbm asukoht',
    'debug_image_upload' => 'Debugi piltide leslaadimist?',
    'keep_unscaled_image' => 'Silita originaalsuuruses pilt?',
    'allow_user_scaling' => 'Luba kasutajal suurendamine?',
    'jpeg_quality' => 'JPEG kvaliteet?',
    'max_image_width' => 'maks. pildi laius?',
    'max_image_height' => 'Maks. pildi krgus?',
    'max_image_size' => 'Maks. pildi suurus?',
    'max_topicicon_width' => 'Maks. rubriigi ikooni laius?',
    'max_topicicon_height' => 'Maks. rubriigi ikooni krgus?',
    'max_topicicon_size' => 'Maks. rubriigi ikooni suurus?',
    'max_photo_width' => 'Maks. foto laius?',
    'max_photo_height' => 'Maks foto krgus?',
    'max_photo_size' => 'Maks. foto suurus?',
    'use_gravatar' => 'Kasuta Gravatar?',
    'gravatar_rating' => 'Luba Gravatari hindamine',
    'force_photo_width' => 'Mra Photo laius',
    'default_photo' => 'Vaikimisi Photo',
    'commentspeedlimit' => 'Kommenteerimise kiirusepiirang',
    'comment_limit' => 'Kommentaaride piir',
    'comment_mode' => 'Kommentaaride viis',
    'comment_code' => 'Vaikimisi kommenteerimine',
    'comment_edit' => 'Luba kommentaaride muutmine?',
    'comment_edittime' => 'Kommentaaride muutmise aeg (sekundid)',
    'commentsubmission' => 'Puhverda kommentaaride sisestamine',
    'passwordspeedlimit' => 'Salasna kiirusepiirang',
    'login_attempts' => 'Maks. sisselogimiskatseid',
    'login_speedlimit' => 'sisselogimise kiirusepiirang',
    'user_html' => 'Kasutaja HTML',
    'admin_html' => 'Admini HTML',
    'advanced_html' => 'Additional HTML for Adv. Editor',
    'skip_html_filter_for_root' => 'Jta HTML filter root jaoks vahele?',
    'allowed_protocols' => 'Lubatud protokollid',
    'disable_autolinks' => 'Keela autolingid?',
    'clickable_links' => 'Tee URL-id klikitavaks?',
    'compressed_output' => 'Saada vljund tihendatult?',
    'frame_options' => 'Kaitse "clickjacking" vastu',
    'censormode' => 'Tsensuurireiim?',
    'censorreplace' => 'Tsensuuri asendustekst',
    'censorlist' => 'Tsenseerimisloetelu',
    'ip_lookup' => 'IP otsing',
    'url_rewrite' => 'Luba URL-i lekirjutamine',
    'meta_tags' => 'Meta Tags',
    'meta_description' => 'Default Meta Description',
    'meta_keywords' => 'Default Meta Keywords',
    'default_permissions_block' => 'Bloki vaikimisi igused',
    'default_permissions_story' => 'Lugude vaikimisi igused',
    'default_permissions_topic' => 'Rubriigi vaikimisi igused',
    'atom_max_stories' => 'Maks. lugusid veebiteenuste limedes',
    'disable_webservices' => 'Keela veebiteenused?',
    'restrict_webservices' => 'Piira veebiteenused?',
    'article_comment_close_enabled' => 'Automatically close comments (default)',
    'article_comment_close_days' => 'Sulge kommenteerimine pevaga (vaikimisi)',
    'comment_close_rec_stories' => 'Uusimate lugude arv, mida on lubatud kommenteerida',
    'allow_reply_notifications' => 'Luba kommentaarile vastamisest teavitamine?',
    'search_style' => 'Tulemuste loetelu stiil',
    'search_limits' => 'Lehe limiit',
    'search_show_num' => 'Nitatulemuste arvu?',
    'search_show_type' => 'Nita tulemuse tpi?',
    'search_show_sort' => 'Luba kasutajal tulemusi sorteerida?',
    'search_show_limit' => 'Nita lehe limiiti?',
    'search_separator' => 'Grupi eraldaja',
    'search_def_keytype' => 'Vaikimisi otsimisviis'
);

$LANG_configsubgroups['Core'] = array(
    'sg_site' => 'Leht',
    'sg_stories' => 'Lood ja Trackback',
    'sg_theme' => 'Skeem',
    'sg_blocks' => 'Blokid',
    'sg_users' => 'Kasutajad ja sisestused',
    'sg_images' => 'Pildid',
    'sg_locale' => 'Keel ja asukoht',
    'sg_misc' => 'Mitmesugust'
);

$LANG_fs['Core'] = array(
    'fs_site' => 'Leht',
    'fs_paths' => 'Asukohad',
    'fs_theme' => 'Skeem',
    'fs_mail' => 'E-post',
    'fs_pear' => 'Pear',
    'fs_mysql' => 'MySQL',
    'fs_users' => 'Kasutajad',
    'fs_misc' => 'Mitmesugust',
    'fs_spamx' => 'Spam-X',
    'fs_admin_block' => 'Admin Blokk',
    'fs_locale' => 'Asukoht',
    'fs_language' => 'Keel',
    'fs_debug' => 'Debug',
    'fs_cookies' => 'Kpsised',
    'fs_login' => 'Sisselogimise hlestus',
    'fs_search' => 'Otsing',
    'fs_user_submission' => 'Kasutaja sisestused',
    'fs_submission' => 'Sisestuse hlestused',
    'fs_topics_block' => 'Rubriigi blokk',
    'fs_whosonline_block' => 'Kes on  Online Blokk',
    'fs_daily_digest' => 'Pevased kokkuvtted',
    'fs_whatsnew_block' => 'Mida uut Blokk',
    'fs_trackback' => 'Trackback',
    'fs_pingback' => 'Pingback',
    'fs_story' => 'Lugu',
    'fs_theme_advanced' => 'Keerukamad hlestused',
    'fs_syndication' => 'Limed',
    'fs_imagelib' => 'Pilditeek',
    'fs_upload' => 'leslaadimine',
    'fs_articleimg' => 'Pildid lugudes',
    'fs_topicicon' => 'Rubriigi ikoonid',
    'fs_userphoto' => 'Fotod',
    'fs_gravatar' => 'Gravatar',
    'fs_comments' => 'Kommentaarid',
    'fs_htmlfilter' => 'HTML filtreerimine',
    'fs_censoring' => 'Tsenseerimine',
    'fs_iplookup' => 'IP otsing',
    'fs_perm_story' => 'Loo vaikimisi igused',
    'fs_perm_topic' => 'Rubriigi vaikimisi igused',
    'fs_perm_block' => 'Bloki vaikimisi igused',
    'fs_webservices' => 'Veebiteenused'
);

$LANG_configselects['Core'] = array(
    0 => array('Jah' => 1, 'Ei' => 0),
    1 => array('Jah' => true, 'Ei' => false),
    2 => array('Lkka tagasi' => 0, 'Jta ainult viimane' => 1, 'Luba mitut postitust' => 2),
    3 => array('Trackback lubatud' => 0, 'Trackback keelatud' => -1),
    4 => array('Ei kontrolli midagi' => 0, 'Kontrolli saidi URL-i' => 1, 'Kontrolli Tis URL-i' => 2, 'Kontrolli saidi URL-i ja tis URL-i' => 3, 'Vrdle IP saidi IP-ga' => 4, 'Kontrolli IP ja saidi URL-i' => 5, 'Kontrolli IP ja tis URL-i' => 6, 'Kontrolli IP, tis URL-i, ja saidi URL-i' => 7),
    5 => array('Puhas tekst' => 'plaintext', 'HTML kujundusega' => 'html'),
    6 => array('12' => 12, '24' => 24),
    7 => array('Viimane leht' => 'last', 'Esimene leht' => 'first', 'Iga leht' => 'all'),
    8 => array('Parem' => 'right', 'Vasak' => 'left'),
    9 => array('Suuna edasi lehele' => 'item', 'Nita loetelu' => 'list', 'Nita avalehte' => 'home', 'Nita admini lehte' => 'admin'),
    10 => array('Mitte midagi' => '', 'Netpbm' => 'netpbm', 'ImageMagick' => 'imagemagick', 'gdLib' => 'gdlib'),
    11 => array('lihtne' => 'flat', 'ksteise sees' => 'nested', 'Limedena' => 'threaded', 'pole kommentaare' => 'nocomment'),
    12 => array('Pole ligipsu' => 0, 'Ainult loetav' => 2, 'Loetav ja muudetav' => 3),
    13 => array('Jta vahele' => 0, 'Luba kiiruspiiranguga' => 1, 'Luba ilma kiiruspiiranguta' => 2),
    14 => array('Phapev' => 'Sun', 'Esmaspev' => 'Mon'),
    15 => array('Arvuliselt' => 'sortnum', 'Thestikuliselt' => 'alpha'),
    16 => array('Sisselogimine pole tarvilik' => 0, 'Tpsem otsing' => 1, 'Lihtne ja tpsem otsing' => 2),
    17 => array('Kommenteerimine lubatud' => 0, 'Kommenteerimine keelatud' => -1),
    18 => array('Keelatud' => 0, 'Lubatud (tpne kattumine)' => 1, 'Lubatud (sna algus)' => 2, 'Lubatud (sna osa)' => 3),
    19 => array('Google' => 'google', 'Tabel' => 'table'),
    20 => array('Tpne fraas' => 'phrase', 'Kik snad' => 'all', 'Mni snadest' => 'any'),
    21 => array('HTML 4.01 Transitional' => 'html401transitional', 'HTML 4.01 Strict' => 'html401strict', 'XHTML 1.0 Transitional' => 'xhtml10transitional', 'XHTML 1.0 Strict' => 'xhtml10strict'),
    22 => array('Range' => 'DENY', 'Sama allikas' => 'SAMEORIGIN', '(vljas)' => ''),
    23 => array('Disabled' => 0, 'Enabled' => 1, 'Enabled (Default for Homepage only)' => 2)
);

?>
